@@ -34,7 +34,7 @@ sub show_dialog_edit {
         &addrow_msg_log("Retrieving guest settings for $$gref{Name}...");
         $vmc{IMachine} = $$sref{IMachine};
         $vmc{USBFilters} = IMachine_getUSBDeviceFilters($vmc{IMachine});
-        $vmc{IBIOSSettings} = IMachine_getBIOSSettings($vmc{IMachine});
+        $vmc{IFirmwareSettings} = IMachine_getFirmwareSettings($vmc{IMachine});
         $vmc{IGraphicsAdapter} = IMachine_getGraphicsAdapter($vmc{IMachine});
         $vmc{IAudioSettings} = IMachine_getAudioSettings($vmc{IMachine});
         $vmc{IAudioAdapter} = IAudioSettings_getAdapter($vmc{IAudioSettings});
@@ -42,6 +42,8 @@ sub show_dialog_edit {
         $vmc{IParallelPort} = IMachine_getParallelPort($vmc{IMachine}, 0);
         $vmc{IRecordingSettings} = IMachine_getRecordingSettings($vmc{IMachine});
         $vmc{IRecordingScreenSettings} = IRecordingSettings_getScreenSettings($vmc{IRecordingSettings}, 0); # We only support 1 screen.
+        $vmc{IPlatform} = IMachine_getPlatform($vmc{IMachine});
+        $vmc{IPlatformX86} = IPlatform_getX86($vmc{IPlatform});
         $vmc{IHost} = IVirtualBox_getHost($gui{websn});
         $vmc{Name} = $$gref{Name};
         $vmc{SessionType} = $$sref{Type};
