@@ -17,16 +17,16 @@ sub init_edit_disp_screen() {
     $gui{spinbuttonEditDispVidMem}->set_value(IGraphicsAdapter_getVRAMSize($vmc{IGraphicsAdapter}));
     $gui{spinbuttonEditDispMonitor}->set_range($$vhost{minmonitors}, $$vhost{maxmonitors});
     $gui{spinbuttonEditDispMonitor}->set_value(IGraphicsAdapter_getMonitorCount($vmc{IGraphicsAdapter}));
-    $gui{checkbuttonEditDisp3D}->set_active(&bl(IGraphicsAdapter_getAccelerate3DEnabled($vmc{IGraphicsAdapter})));
-    $gui{checkbuttonEditDisp2D}->set_active(&bl(IGraphicsAdapter_getAccelerate2DVideoEnabled($vmc{IGraphicsAdapter})));
+    $gui{checkbuttonEditDisp3D}->set_active(&bl(IGraphicsAdapter_isFeatureEnabled($vmc{IGraphicsAdapter}, 'Acceleration3D')));
+    $gui{checkbuttonEditDisp2D}->set_active(&bl(IGraphicsAdapter_isFeatureEnabled($vmc{IGraphicsAdapter}, 'Acceleration2DVideo')));
     &set_pointer($gui{dialogEdit});
 }
 
 # Set whether 2D acceleration is enabled
-sub disp_scr_2D { IGraphicsAdapter_setAccelerate2DVideoEnabled($vmc{IGraphicsAdapter}, $gui{checkbuttonEditDisp2D}->get_active()); }
+sub disp_scr_2D { IGraphicsAdapter_setFeature($vmc{IGraphicsAdapter}, 'Acceleration2DVideo', $gui{checkbuttonEditDisp2D}->get_active()); }
 
 # Set whether 3D accelerator is enabled.
-sub disp_scr_3D { IGraphicsAdapter_setAccelerate3DEnabled($vmc{IGraphicsAdapter}, $gui{checkbuttonEditDisp3D}->get_active()); }
+sub disp_scr_3D { IGraphicsAdapter_setFeature($vmc{IGraphicsAdapter}, 'Acceleration3D', $gui{checkbuttonEditDisp3D}->get_active()); }
 
 # Set the virtual VGA card type
 sub disp_scr_VGA { if ($vmc{SessionType} eq 'WriteLock') { IGraphicsAdapter_setGraphicsControllerType($vmc{IGraphicsAdapter}, &getsel_combo($gui{comboboxEditDispVGA}, 0)); } }
