@@ -11,26 +11,26 @@ sub init_edit_gen_advanced {
     if ($$vhost{autostartdb}) {
         $gui{comboboxEditGenAutostop}->set_sensitive(1);
         $gui{checkbuttonEditGenAutostart}->set_sensitive(1);
-        $gui{spinbuttonEditGenAutostartDelay}->set_sensitive(1);
+        $gui{sbEditGenAutostartDelay}->set_sensitive(1);
         $gui{labelEditGenAutostartDelay}->set_sensitive(1);
         $gui{labelEditGenAutostop}->set_sensitive(1);
         &combobox_set_active_text($gui{comboboxEditGenAutostop}, IMachine_getAutostopType($vmc{IMachine}), 0);
         $gui{checkbuttonEditGenAutostart}->set_active(&bl(IMachine_getAutostartEnabled($vmc{IMachine})));
-        $gui{spinbuttonEditGenAutostartDelay}->set_value(IMachine_getAutostartDelay($vmc{IMachine}));
+        $gui{sbEditGenAutostartDelay}->set_value(IMachine_getAutostartDelay($vmc{IMachine}));
     }
     else {
         $gui{comboboxEditGenAutostop}->set_sensitive(0);
         $gui{checkbuttonEditGenAutostart}->set_sensitive(0);
-        $gui{spinbuttonEditGenAutostartDelay}->set_sensitive(0);
+        $gui{sbEditGenAutostartDelay}->set_sensitive(0);
         $gui{labelEditGenAutostartDelay}->set_sensitive(0);
         $gui{labelEditGenAutostop}->set_sensitive(0);
     }
 
-    $gui{entryEditGenSnapFolder}->signal_handler_block($signal{snapfolderactivate});
-    $gui{entryEditGenSnapFolder}->signal_handler_block($signal{snapfolderfocus});
+    $gui{entryEditGenSnapFolder}->signal_handler_block($signal{entryEditGenSnapFolder_activate});
+    $gui{entryEditGenSnapFolder}->signal_handler_block($signal{entryEditGenSnapFolder_focus});
     $gui{entryEditGenSnapFolder}->set_text(IMachine_getSnapshotFolder($vmc{IMachine}));
-    $gui{entryEditGenSnapFolder}->signal_handler_unblock($signal{snapfolderactivate});
-    $gui{entryEditGenSnapFolder}->signal_handler_block($signal{snapfolderfocus});
+    $gui{entryEditGenSnapFolder}->signal_handler_unblock($signal{entryEditGenSnapFolder_activate});
+    $gui{entryEditGenSnapFolder}->signal_handler_block($signal{entryEditGenSnapFolder_focus});
     &set_pointer($gui{dialogEdit});
 }
 
@@ -59,7 +59,7 @@ sub gen_adv_autostop_mode {
 
 # Set the autostart delay in seconds
 sub gen_adv_autostart_delay {
-    IMachine_setAutostartDelay($vmc{IMachine}, $gui{spinbuttonEditGenAutostartDelay}->get_value_as_int());
+    IMachine_setAutostartDelay($vmc{IMachine}, $gui{sbEditGenAutostartDelay}->get_value_as_int());
     return 0; # Must return this value for the signal used.
 }
 
