@@ -8,7 +8,7 @@ sub init_edit_io_serial {
     my $port = &getsel_combo($gui{comboboxEditIOSelectedSerial}, 1);
     my $ISerialPort = IMachine_getSerialPort($vmc{IMachine}, $port);
     my $irq = ISerialPort_getIRQ($ISerialPort);
-    my $ioport = sprintf('%X', ISerialPort_getIOBase($ISerialPort));
+    my $ioport = sprintf('%X', ISerialPort_getIOAddress($ISerialPort));
     my $mode = ISerialPort_getHostMode($ISerialPort);
     $gui{checkbuttonEditSerialEnable}->set_active(&bl(ISerialPort_getEnabled($ISerialPort)));
     $gui{tableEditSerial}->set_sensitive($gui{checkbuttonEditSerialEnable}->get_active()); # Ghost/Unghost other widgets based on serial enabled
@@ -73,7 +73,7 @@ sub io_ser_port {
 
         if ($ioport) {
             my ($ISerialPort, $port) = &io_ser_callout();
-            ISerialPort_setIOBase($ISerialPort, hex($ioport));
+            ISerialPort_setIOAddress($ISerialPort, hex($ioport));
         }
     }
 
