@@ -6,15 +6,15 @@ our (%gui, %signal, %vmc);
 sub init_edit_network {
     &set_pointer($gui{dialogEdit}, 'watch');
     my $slot = &getsel_combo($gui{comboboxEditNetSelectedAdapter}, 1);
-    $gui{comboboxEditNetType}->signal_handler_block($signal{netadaptype});
+    $gui{comboboxEditNetType}->signal_handler_block($signal{comboboxEditNetType_changed});
     $gui{comboboxEditNetAttach}->signal_handler_block($signal{comboboxEditNetAttach_changed});
-    $gui{comboboxEditNetName}->signal_handler_block($signal{netname});
-    $gui{comboboxentryEditNetGenDriver}->signal_handler_block($signal{genericdrv});
-    $gui{comboboxentryEditNetNameInt}->signal_handler_block($signal{nameint});
+    $gui{comboboxEditNetName}->signal_handler_block($signal{comboboxEditNetName_changed});
+    $gui{comboboxentryEditNetGenDriver}->signal_handler_block($signal{comboboxentryEditNetGenDriver_changed});
+    $gui{comboboxentryEditNetNameInt}->signal_handler_block($signal{comboboxentryEditNetNameInt_changed});
     $gui{liststoreEditNetName}->clear();
     $gui{liststoreEditNetGenDriver}->clear();
     $gui{liststoreEditNetNameInt}->clear();
-    $gui{textbufferEditNetGeneric}->set_text('');
+    $gui{txtbEditNetGeneric}->set_text('');
 
     my $IHost = IVirtualBox_getHost($gui{websn});
     my $INetworkAdapter = IMachine_getNetworkAdapter($vmc{IMachine}, $slot);
@@ -38,11 +38,11 @@ sub init_edit_network {
     elsif ($AttachType eq 'NAT') { &net_gui_nat(); }
     else { &net_gui_notattached($INetworkAdapter, $slot); } # Assume Null
 
-    $gui{comboboxEditNetType}->signal_handler_unblock($signal{netadaptype});
+    $gui{comboboxEditNetType}->signal_handler_unblock($signal{comboboxEditNetType_changed});
     $gui{comboboxEditNetAttach}->signal_handler_unblock($signal{comboboxEditNetAttach_changed});
-    $gui{comboboxEditNetName}->signal_handler_unblock($signal{netname});
-    $gui{comboboxentryEditNetGenDriver}->signal_handler_unblock($signal{genericdrv});
-    $gui{comboboxentryEditNetNameInt}->signal_handler_unblock($signal{nameint});
+    $gui{comboboxEditNetName}->signal_handler_unblock($signal{comboboxEditNetName_changed});
+    $gui{comboboxentryEditNetGenDriver}->signal_handler_unblock($signal{comboboxentryEditNetGenDriver_changed});
+    $gui{comboboxentryEditNetNameInt}->signal_handler_unblock($signal{comboboxentryEditNetNameInt_changed});
     &set_pointer($gui{dialogEdit});
     return 0;
 }
@@ -109,7 +109,7 @@ sub net_generic_properties {
         foreach (0 .. int(@cprops / 2) - 1) { INetworkAdapter_setProperty($INetworkAdapter, $cprops[$_], ''); }
     }
 
-    my $textbuffer = $gui{textbufferEditNetGeneric};
+    my $textbuffer = $gui{txtbEditNetGeneric};
     my $count = $textbuffer->get_line_count();
 
     foreach my $linenum (0 .. ($count - 1)) {
@@ -136,9 +136,9 @@ sub net_adapter_type {
 sub net_attach {
     my ($widget) = @_;
     my $INetworkAdapter = &net_callout();
-    $gui{comboboxEditNetName}->signal_handler_block($signal{netname});
-    $gui{comboboxentryEditNetGenDriver}->signal_handler_block($signal{genericdrv});
-    $gui{comboboxentryEditNetNameInt}->signal_handler_block($signal{nameint});
+    $gui{comboboxEditNetName}->signal_handler_block($signal{comboboxEditNetName_changed});
+    $gui{comboboxentryEditNetGenDriver}->signal_handler_block($signal{comboboxentryEditNetGenDriver_changed});
+    $gui{comboboxentryEditNetNameInt}->signal_handler_block($signal{comboboxentryEditNetNameInt_changed});
     my $IHost = IVirtualBox_getHost($gui{websn});
     my $AttachType = &getsel_combo($widget, 0);
     $gui{liststoreEditNetName}->clear();
@@ -152,9 +152,9 @@ sub net_attach {
     elsif ($AttachType eq 'Generic') { &net_gui_generic($INetworkAdapter); }
     else { &net_gui_notattached($INetworkAdapter); }
 
-    $gui{comboboxentryEditNetGenDriver}->signal_handler_unblock($signal{genericdrv});
-    $gui{comboboxentryEditNetNameInt}->signal_handler_unblock($signal{nameint});
-    $gui{comboboxEditNetName}->signal_handler_unblock($signal{netname});
+    $gui{comboboxentryEditNetGenDriver}->signal_handler_unblock($signal{comboboxentryEditNetGenDriver_changed});
+    $gui{comboboxentryEditNetNameInt}->signal_handler_unblock($signal{comboboxentryEditNetNameInt_changed});
+    $gui{comboboxEditNetName}->signal_handler_unblock($signal{comboboxEditNetName_changed});
     $gui{comboboxEditNetName}->set_active(0); # This will call net_name()
 }
 
@@ -329,7 +329,7 @@ sub net_gui_generic {
         foreach (0 .. scalar(@props_keys) - 1) { $proptext .= "$props_keys[$_]" . '=' . "$props_vals[$_]\n"; }
     }
 
-    $gui{textbufferEditNetGeneric}->set_text($proptext) if ($proptext);
+    $gui{txtbEditNetGeneric}->set_text($proptext) if ($proptext);
 
     foreach my $driver (@genericlist) {
             my $iter = $gui{liststoreEditNetGenDriver}->append();
