@@ -83,23 +83,23 @@ sub init_edit_storage {
 # Handle the radio button sensitivity when selecting an image format when
 # creating a hard disk
 sub storage_sens_create_hd {
-    my $format = &getsel_combo($gui{comboboxCreateHDFormat}, 1);
-    $gui{radiobuttonCreateHDDynamic}->set_active(1);
+    my $format = &getsel_combo($gui{d}{CreateHD}{cboxFormat}, 1);
+    $gui{d}{CreateHD}{radioDynamic}->set_active(1);
 
     if ($format eq 'vmdk') {
-        $gui{radiobuttonCreateHDDynamic}->show();
-        $gui{radiobuttonCreateHDFixed}->show();
-        $gui{radiobuttonCreateHDSplit}->show();
+        $gui{d}{CreateHD}{radioDynamic}->show();
+        $gui{d}{CreateHD}{radioFixed}->show();
+        $gui{d}{CreateHD}{radioSplit}->show();
     }
     elsif ($format eq 'vdi' or $format eq 'vhd') {
-        $gui{radiobuttonCreateHDDynamic}->show();
-        $gui{radiobuttonCreateHDFixed}->show();
-        $gui{radiobuttonCreateHDSplit}->hide();
+        $gui{d}{CreateHD}{radioDynamic}->show();
+        $gui{d}{CreateHD}{radioFixed}->show();
+        $gui{d}{CreateHD}{radioSplit}->hide();
     }
     else {
-        $gui{radiobuttonCreateHDDynamic}->show();
-        $gui{radiobuttonCreateHDFixed}->hide();
-        $gui{radiobuttonCreateHDSplit}->hide();
+        $gui{d}{CreateHD}{radioDynamic}->show();
+        $gui{d}{CreateHD}{radioFixed}->hide();
+        $gui{d}{CreateHD}{radioSplit}->hide();
     }
 }
 
