@@ -5,8 +5,8 @@ our (%gui, %vmc);
 
 sub init_edit_sys_accel {
     &set_pointer($gui{dialogEdit}, 'watch');
-    $gui{checkbuttonEditSysNested}->set_active(&bl(IMachine_getHWVirtExProperty($vmc{IMachine}, 'NestedPaging')));
-    $gui{checkbuttonEditSysVPID}->set_active(&bl(IMachine_getHWVirtExProperty($vmc{IMachine}, 'VPID')));
+    $gui{checkbuttonEditSysNested}->set_active(&bl(IPlatformX86_getHWVirtExProperty($vmc{IPlatformX86}, 'NestedPaging')));
+    $gui{checkbuttonEditSysVPID}->set_active(&bl(IPlatformX86_getHWVirtExProperty($vmc{IPlatformX86}, 'VPID')));
     &combobox_set_active_text($gui{comboboxEditSysParavirt}, IMachine_getParavirtProvider($vmc{IMachine}), 0);
     &set_pointer($gui{dialogEdit});
 }
@@ -15,9 +15,9 @@ sub init_edit_sys_accel {
 sub sys_accel_paravirt { if ($vmc{SessionType} eq 'WriteLock') { IMachine_setParavirtProvider($vmc{IMachine}, &getsel_combo($gui{comboboxEditSysParavirt}, 0)); } }
 
 # Whether the guest uses Nested Paging
-sub sys_accel_nested_paging { if ($vmc{SessionType} eq 'WriteLock') { IMachine_setHWVirtExProperty($vmc{IMachine}, 'NestedPaging', $gui{checkbuttonEditSysNested}->get_active()); } }
+sub sys_accel_nested_paging { if ($vmc{SessionType} eq 'WriteLock') { IPlatformX86_setHWVirtExProperty($vmc{IPlatformX86}, 'NestedPaging', $gui{checkbuttonEditSysNested}->get_active()); } }
 
 # Whether the guest uses VPID
-sub sys_accel_vpid { if ($vmc{SessionType} eq 'WriteLock') { IMachine_setHWVirtExProperty($vmc{IMachine}, 'VPID', $gui{checkbuttonEditSysVPID}->get_active()); } }
+sub sys_accel_vpid { if ($vmc{SessionType} eq 'WriteLock') { IPlatformX86_setHWVirtExProperty($vmc{IPlatformX86}, 'VPID', $gui{checkbuttonEditSysVPID}->get_active()); } }
 
 1;
