@@ -14,7 +14,7 @@ sub init_edit_sys_mother {
     # Secureboot requires EFI so only enable it. It may also need to be initialised ultimately
     $gui{checkbuttonEditSysSecureBoot}->signal_handler_block($signal{checkbuttonEditSysSecureBoot_toggled});
 
-    if (IMachine_getFirmwareType($vmc{IMachine}) =~ m/^EFI/) {
+    if (IFirmwareSettings_getFirmwareType($vmc{IFirmwareSettings}) =~ m/^EFI/) {
         $gui{checkbuttonEditSysEFI}->set_active(1);
         $gui{checkbuttonEditSysSecureBoot}->set_sensitive(1);
         $gui{buttonEditSysResetBootKeys}->set_sensitive(1);
@@ -33,9 +33,9 @@ sub init_edit_sys_mother {
     $gui{checkbuttonEditSysSecureBoot}->signal_handler_unblock($signal{checkbuttonEditSysSecureBoot_toggled});
     $gui{spinbuttonEditSysMem}->set_range($$vhost{minguestram}, $$vhost{memsize});
     $gui{spinbuttonEditSysMem}->set_value(IMachine_getMemorySize($vmc{IMachine}));
-    $gui{checkbuttonEditSysAPIC}->set_active(&bl(IBIOSSettings_getIOAPICEnabled($vmc{IBIOSSettings})));
-    $gui{checkbuttonEditSysUTC}->set_active(&bl(IMachine_getRTCUseUTC($vmc{IMachine})));
-    &combobox_set_active_text($gui{comboboxEditSysChipset}, IMachine_getChipsetType($vmc{IMachine}), 0);
+    $gui{checkbuttonEditSysAPIC}->set_active(&bl(IFirmwareSettings_getIOAPICEnabled($vmc{IFirmwareSettings})));
+    $gui{checkbuttonEditSysUTC}->set_active(&bl(IPlatform_getRTCUseUTC($vmc{IPlatform})));
+    &combobox_set_active_text($gui{comboboxEditSysChipset}, IPlatform_getChipsetType($vmc{IPlatform}), 0);
     &combobox_set_active_text($gui{comboboxEditSysPointing}, IMachine_getPointingHIDType($vmc{IMachine}), 0);
     &combobox_set_active_text($gui{comboboxEditSysKeyboard}, IMachine_getKeyboardHIDType($vmc{IMachine}), 0);
 
@@ -63,7 +63,7 @@ sub init_edit_sys_mother {
         if ($bootorder{$dev} == $$vhost{maxbootpos} + 1) {
             my $iter = $gui{liststoreEditSysBoot}->append();
             $gui{liststoreEditSysBoot}->set($iter, [0, 1, 2, 3], [0, $dev, $gui{pb}{$dev}, $devdesc{$dev}]);
-        }
+       }
         else {
             my $iter = $gui{liststoreEditSysBoot}->append();
             $gui{liststoreEditSysBoot}->set($iter, [0, 1, 2, 3], [1, $dev, $gui{pb}{$dev}, $devdesc{$dev}]);
@@ -93,19 +93,19 @@ sub sys_mother_mem {
 
 # Sets with IO APIC should be enabled or not in the guest
 sub sys_mother_ioapic {
-    if ($vmc{SessionType} eq 'WriteLock') { IBIOSSettings_setIOAPICEnabled($vmc{IBIOSSettings}, $gui{checkbuttonEditSysAPIC}->get_active()); }
+    if ($vmc{SessionType} eq 'WriteLock') { IFirmwareSettings_setIOAPICEnabled($vmc{IFirmwareSettings}, $gui{checkbuttonEditSysAPIC}->get_active()); }
 }
 
 # Sets whether the machine should use EFI or the traditional BIOS
 sub sys_mother_efi {
     if ($vmc{SessionType} eq 'WriteLock') {
         if ($gui{checkbuttonEditSysEFI}->get_active() == 1) {
-            IMachine_setFirmwareType($vmc{IMachine}, 'EFI');
+            IFirmwareSettings_setFirmwareType($vmc{IFirmwareSettings}, 'EFI');
             $gui{checkbuttonEditSysSecureBoot}->set_sensitive(1);
             $gui{buttonEditSysResetBootKeys}->set_sensitive(1);
         }
         else {
-            IMachine_setFirmwareType($vmc{IMachine}, 'BIOS');
+            IFirmwareSettings_setFirmwareType($vmc{IFirmwareSettings}, 'BIOS');
             $gui{checkbuttonEditSysSecureBoot}->set_sensitive(0);
             $gui{buttonEditSysResetBootKeys}->set_sensitive(0);
         }
@@ -122,7 +122,7 @@ sub sys_mother_tpm {
 
 # Sets whether the guest clock is UTC or local time
 sub sys_mother_utc {
-    if ($vmc{SessionType} eq 'WriteLock') { IMachine_setRTCUseUTC($vmc{IMachine}, $gui{checkbuttonEditSysUTC}->get_active()); }
+    if ($vmc{SessionType} eq 'WriteLock') { IPlatform_setRTCUseUTC($vmc{IPlatform}, $gui{checkbuttonEditSysUTC}->get_active()); }
 }
 
 # Sets whether secure boot is enabled
@@ -158,7 +158,7 @@ sub sys_mother_keyboard {
 
 # Sets the emulated motherboard chipset
 sub sys_mother_chipset {
-    if ($vmc{SessionType} eq 'WriteLock') { IMachine_setChipsetType($vmc{IMachine}, &getsel_combo($gui{comboboxEditSysChipset}, 0)); }
+    if ($vmc{SessionType} eq 'WriteLock') { IPlatform_setChipsetType($vmc{IPlatform}, &getsel_combo($gui{comboboxEditSysChipset}, 0)); }
 }
 
 # Moves the boot device to a higher priority
