@@ -45,50 +45,51 @@ sub init_edit_usb {
 # Shows the dialog for adding or editing a USB filter
 sub show_dialog_usbfilter {
     my $filref = &getsel_list_usbfilters;
-    $gui{entryUSBFilterName}->set_text(IUSBDeviceFilter_getName($$filref{IUSBDeviceFilter}));
-    $gui{entryUSBFilterVendorID}->set_text(IUSBDeviceFilter_getVendorId($$filref{IUSBDeviceFilter}));
-    $gui{entryUSBFilterProductID}->set_text(IUSBDeviceFilter_getProductId($$filref{IUSBDeviceFilter}));
-    $gui{entryUSBFilterRevision}->set_text(IUSBDeviceFilter_getRevision($$filref{IUSBDeviceFilter}));
-    $gui{entryUSBFilterManufacturer}->set_text(IUSBDeviceFilter_getManufacturer($$filref{IUSBDeviceFilter}));
-    $gui{entryUSBFilterProduct}->set_text(IUSBDeviceFilter_getProduct($$filref{IUSBDeviceFilter}));
-    $gui{entryUSBFilterSerial}->set_text(IUSBDeviceFilter_getSerialNumber($$filref{IUSBDeviceFilter}));
-    $gui{entryUSBFilterPort}->set_text(IUSBDeviceFilter_getPort($$filref{IUSBDeviceFilter}));
-    &combobox_set_active_text($gui{comboboxUSBFilterRemote}, IUSBDeviceFilter_getRemote($$filref{IUSBDeviceFilter}), 0);
+    $gui{d}{USBFilter}{entryName}->set_text(IUSBDeviceFilter_getName($$filref{IUSBDeviceFilter}));
+    $gui{d}{USBFilter}{entryVendorID}->set_text(IUSBDeviceFilter_getVendorId($$filref{IUSBDeviceFilter}));
+    $gui{d}{USBFilter}{entryProductID}->set_text(IUSBDeviceFilter_getProductId($$filref{IUSBDeviceFilter}));
+    $gui{d}{USBFilter}{entryRev}->set_text(IUSBDeviceFilter_getRevision($$filref{IUSBDeviceFilter}));
+    $gui{d}{USBFilter}{entryManufacturer}->set_text(IUSBDeviceFilter_getManufacturer($$filref{IUSBDeviceFilter}));
+    $gui{d}{USBFilter}{entryProduct}->set_text(IUSBDeviceFilter_getProduct($$filref{IUSBDeviceFilter}));
+    $gui{d}{USBFilter}{entrySerial}->set_text(IUSBDeviceFilter_getSerialNumber($$filref{IUSBDeviceFilter}));
+    $gui{d}{USBFilter}{entryPort}->set_text(IUSBDeviceFilter_getPort($$filref{IUSBDeviceFilter}));
+    &combobox_set_active_text($gui{d}{USBFilter}{cboxRemote}, IUSBDeviceFilter_getRemote($$filref{IUSBDeviceFilter}), 0);
 
     do {
-        my $response = $gui{dialogUSBFilter}->run;
+        $gui{d}{USBFilter}->show_all;
+        my $response = $gui{d}{USBFilter}->run();
 
         if ($response eq 'ok') {
             # Other entries do not require validation
-            if (!$gui{entryUSBFilterName}->get_text()) { &show_err_msg('invalidname'); }
+            if (!$gui{d}{USBFilter}{entryName}->get_text()) { &show_err_msg('invalidname'); }
             else {
-                $gui{dialogUSBFilter}->hide;
+                $gui{d}{USBFilter}->hide;
                 IUSBDeviceFilters_removeDeviceFilter($vmc{USBFilters}, $$filref{Position}); # Remove the original filter
                 # Create the new filter based on the old
-                my $newfilter = IUSBDeviceFilters_createDeviceFilter($vmc{USBFilters}, $gui{entryUSBFilterName}->get_text());
+                my $newfilter = IUSBDeviceFilters_createDeviceFilter($vmc{USBFilters}, $gui{d}{USBFilter}{entryName}->get_text());
                 IUSBDeviceFilter_setActive($newfilter, $$filref{Enabled});
-                IUSBDeviceFilter_setVendorId($newfilter, $gui{entryUSBFilterVendorID}->get_text());
-                IUSBDeviceFilter_setProductId($newfilter, $gui{entryUSBFilterProductID}->get_text());
-                IUSBDeviceFilter_setRevision($newfilter, $gui{entryUSBFilterRevision}->get_text());
-                IUSBDeviceFilter_setManufacturer($newfilter, $gui{entryUSBFilterManufacturer}->get_text());
-                IUSBDeviceFilter_setProduct($newfilter, $gui{entryUSBFilterProduct}->get_text());
-                IUSBDeviceFilter_setSerialNumber($newfilter, $gui{entryUSBFilterSerial}->get_text());
-                IUSBDeviceFilter_setPort($newfilter, $gui{entryUSBFilterPort}->get_text());
+                IUSBDeviceFilter_setVendorId($newfilter, $gui{d}{USBFilter}{entryVendorID}->get_text());
+                IUSBDeviceFilter_setProductId($newfilter, $gui{d}{USBFilter}{entryProductID}->get_text());
+                IUSBDeviceFilter_setRevision($newfilter, $gui{d}{USBFilter}{entryRev}->get_text());
+                IUSBDeviceFilter_setManufacturer($newfilter, $gui{d}{USBFilter}{entryManufacturer}->get_text());
+                IUSBDeviceFilter_setProduct($newfilter, $gui{d}{USBFilter}{entryProduct}->get_text());
+                IUSBDeviceFilter_setSerialNumber($newfilter, $gui{d}{USBFilter}{entrySerial}->get_text());
+                IUSBDeviceFilter_setPort($newfilter, $gui{d}{USBFilter}{entryPort}->get_text());
                 IUSBDeviceFilters_insertDeviceFilter($vmc{USBFilters}, $$filref{Position}, $newfilter);
                 # We have to use a string as undef is not allowed in a liststore, so strip the corresponding
                 # string to force it to be undef on retrieval. Messy VB API!
                 # '' = Any (but in the liststore it has to be 'any'
                 # 'yes' = Yes
                 # 'no'  = No
-                my $remote = &getsel_combo($gui{comboboxUSBFilterRemote}, 0);
+                my $remote = &getsel_combo($gui{d}{USBFilter}{cboxRemote}, 0);
                 $remote =~ s/any//g;
                 IUSBDeviceFilter_setRemote($newfilter, $remote);
                 &fill_list_usbfilters($vmc{IMachine});
             }
         }
-        else { $gui{dialogUSBFilter}->hide; }
+        else { $gui{d}{USBFilter}->hide; }
 
-    } until (!$gui{dialogUSBFilter}->get_visible());
+    } until (!$gui{d}{USBFilter}->get_visible());
 }
 
 # Toggles whether USB is enabled or not. Sub is unusual because VB uses the OHCI
