@@ -144,9 +144,9 @@ our (%gui);
 
     sub show_err_msg {
         my ($key, $append) = @_;
-        my $dialog = $gui{messagedialogError};
+        my $dialog = $gui{d}{errorMessageDialog};
         my ($title, $body, $type) = @{ $err{$key} };
-        $dialog = $gui{messagedialogWarning} if ($type eq 'warning');
+        $dialog = $gui{d}{warningMessageDialog} if ($type eq 'warning');
         $body .= "\n$append" if ($append);
         &addrow_msg_log("Error Dialog:    $title:    $body");
         $dialog->set_markup("<big><b>$title</b></big>");
@@ -167,10 +167,10 @@ sub show_invalid_object_msg {
                "but will require you to reconnect.\n\nAdditional:\n";
     $body .= $append if ($append);
     &addrow_msg_log("Error Dialog:    Invalid Object Reference:    $body");
-    $gui{messagedialogInvalidObject}->format_secondary_markup($body);
+    $gui{$gui{d}{invalidobjectMessage}}->format_secondary_markup($body);
 
-    my $response = $gui{messagedialogInvalidObject}->run;
-    $gui{messagedialogInvalidObject}->hide;
+    my $response = $gui{$gui{d}{invalidobjectMessage}}->run;
+    $gui{$gui{d}{invalidobjectMessage}}->hide;
     return $response;
 }
 
