@@ -19,31 +19,33 @@ our (%gui, $sharedir);
     sub init_vhost {
         my $IHost = IVirtualBox_getHost($gui{websn});
         my $ISystemProperties = IVirtualBox_getSystemProperties($gui{websn});
-        %vhost = (ISystemProperties => $ISystemProperties,
-                  IHost             => $IHost,
-                  os                => IHost_getOperatingSystem($IHost),
-                  maxhostcpuon      => IHost_getProcessorOnlineCount($IHost),
-                  memsize           => IHost_getMemorySize($IHost),
-                  machinedir        => ISystemProperties_getDefaultMachineFolder($ISystemProperties),
-                  minhdsize         => 4096, # Not returnable by API but VB itself uses this value
-                  minhdsizemb       => 4, # Not returnable by API but VB itself uses this value
-                  maxhdsize         => ISystemProperties_getInfoVDSize($ISystemProperties),
-                  maxnet            => ISystemProperties_getMaxNetworkAdapters($ISystemProperties, 'PIIX3'),
-                  hwexclusive       => ISystemProperties_getExclusiveHwVirt($ISystemProperties),
-                  maxser            => ISystemProperties_getSerialPortCount($ISystemProperties),
-                  minguestcpu       => ISystemProperties_getMinGuestCPUCount($ISystemProperties),
-                  maxguestcpu       => ISystemProperties_getMaxGuestCPUCount($ISystemProperties),
-                  minguestram       => ISystemProperties_getMinGuestRAM($ISystemProperties),
-                  maxguestram       => ISystemProperties_getMaxGuestRAM($ISystemProperties),
-                  minguestvram      => ISystemProperties_getMinGuestVRAM($ISystemProperties),
-                  maxguestvram      => ISystemProperties_getMaxGuestVRAM($ISystemProperties),
-                  maxbootpos        => ISystemProperties_getMaxBootPosition($ISystemProperties),
-                  minmonitors       => 1, # Not returnable by API
-                  maxmonitors       => ISystemProperties_getMaxGuestMonitors($ISystemProperties),
-                  vrdeextpack       => ISystemProperties_getDefaultVRDEExtPack($ISystemProperties),
-                  vrdelib           => ISystemProperties_getVRDEAuthLibrary($ISystemProperties),
-                  additionsiso      => ISystemProperties_getDefaultAdditionsISO($ISystemProperties),
-                  autostartdb       => ISystemProperties_getAutostartDatabasePath($ISystemProperties));
+        my $IPlatformProperties = ISystemProperties_getPlatform($ISystemProperties);
+        %vhost = (ISystemProperties   => $ISystemProperties,
+                  IPlatformProperties => $IPlatformProperties,
+                  IHost               => $IHost,
+                  os                  => IHost_getOperatingSystem($IHost),
+                  maxhostcpuon        => IHost_getProcessorOnlineCount($IHost),
+                  memsize             => IHost_getMemorySize($IHost),
+                  machinedir          => ISystemProperties_getDefaultMachineFolder($ISystemProperties),
+                  minhdsize           => 4096, # Not returnable by API but VB itself uses this value
+                  minhdsizemb         => 4, # Not returnable by API but VB itself uses this value
+                  maxhdsize           => ISystemProperties_getInfoVDSize($ISystemProperties),
+                  maxnet              => IPlatformProperties_getMaxNetworkAdapters($IPlatformProperties, 'PIIX3'),
+                  hwexclusive         => IPlatformProperties_getExclusiveHwVirt($IPlatformProperties),
+                  maxser              => IPlatformProperties_getSerialPortCount($IPlatformProperties),
+                  minguestcpu         => ISystemProperties_getMinGuestCPUCount($ISystemProperties),
+                  maxguestcpu         => ISystemProperties_getMaxGuestCPUCount($ISystemProperties),
+                  minguestram         => ISystemProperties_getMinGuestRAM($ISystemProperties),
+                  maxguestram         => ISystemProperties_getMaxGuestRAM($ISystemProperties),
+                  minguestvram        => ISystemProperties_getMinGuestVRAM($ISystemProperties),
+                  maxguestvram        => ISystemProperties_getMaxGuestVRAM($ISystemProperties),
+                  maxbootpos          => IPlatformProperties_getMaxBootPosition($IPlatformProperties),
+                  minmonitors         => 1, # Not returnable by API
+                  maxmonitors         => ISystemProperties_getMaxGuestMonitors($ISystemProperties),
+                  vrdeextpack         => ISystemProperties_getDefaultVRDEExtPack($ISystemProperties),
+                  vrdelib             => ISystemProperties_getVRDEAuthLibrary($ISystemProperties),
+                  additionsiso        => ISystemProperties_getDefaultAdditionsISO($ISystemProperties),
+                  autostartdb         => ISystemProperties_getAutostartDatabasePath($ISystemProperties));
 
         # Convenience Keys
         $vhost{maxhdsizemb} = ceil($vhost{maxhdsize} / 1048576);
@@ -59,7 +61,7 @@ our (%gui, $sharedir);
         my @floppy = IHost_getFloppyDrives($IHost);
         $vhost{floppy} = \@floppy;
 
-        my @tpm = ISystemProperties_getSupportedTpmTypes($ISystemProperties);
+        my @tpm = IPlatformProperties_getSupportedTpmTypes($IPlatformProperties);
         $vhost{tpmtypes} = \@tpm;
     }
 }
@@ -84,8 +86,12 @@ our (%gui, $sharedir);
 
     sub init_oslist {
         my @IGuestOSType = IVirtualBox_getGuestOSTypes($gui{websn});
+
         foreach my $type (@IGuestOSType) {
+            next if ($$type{platformArchitecture} ne 'x86'); # For the moment filter out ARM
+
             if (!defined($osfam{$$type{familyId}})) {
+
                 $osfam{$$type{familyId}} = {};
                 $osfam{$$type{familyId}}{verids} = ();
                 $osfam{$$type{familyId}}{icon} = Gtk3::Gdk::Pixbuf->new_from_file("$sharedir/icons/os/$$type{familyId}.png");
@@ -111,6 +117,7 @@ our (%gui, $sharedir);
             $osver{$$type{id}}{recommendedUSBTablet} = $$type{recommendedUSBTablet};
             $osver{$$type{id}}{recommendedHDStorageBus} = $$type{recommendedHDStorageBus};
             $osver{$$type{id}}{recommendedChipset} = $$type{recommendedChipset};
+            $osver{$$type{id}}{recommendedChipset} = $$type{recommendedChipset};
             $osver{$$type{id}}{recommendedFirmware} = $$type{recommendedFirmware};
             $osver{$$type{id}}{recommendedDVDStorageBus} = $$type{recommendedDVDStorageBus};
             $osver{$$type{id}}{recommendedHDStorageController} = $$type{recommendedHDStorageController};
@@ -119,6 +126,17 @@ our (%gui, $sharedir);
             $osver{$$type{id}}{recommended2DVideoAcceleration} = $$type{recommended2DVideoAcceleration};
             $osver{$$type{id}}{recommendedAudioController} = $$type{recommendedAudioController};
             $osver{$$type{id}}{familyId} = $$type{familyId};
+            $osver{$$type{id}}{platformArchitecture} = $$type{platformArchitecture};
+            $osver{$$type{id}}{recommendedSecureBoot} = $$type{recommendedSecureBoot};
+            $osver{$$type{id}}{recommended3DAcceleration} = $$type{recommended3DAcceleration};
+            $osver{$$type{id}}{recommendedIommuType} = $$type{recommendedIommuType};
+            $osver{$$type{id}}{recommendedCPUCount} = $$type{recommendedCPUCount};
+            $osver{$$type{id}}{recommendedTpmType} = $$type{recommendedTpmType};
+            $osver{$$type{id}}{guestAdditionsInstallPackageName} = $$type{guestAdditionsInstallPackageName};
+            $osver{$$type{id}}{recommendedGraphicsController} = $$type{recommendedGraphicsController};
+            $osver{$$type{id}}{recommendedWDDMGraphics} = $$type{recommendedWDDMGraphics};
+            $osver{$$type{id}}{recommendedAudioCodec} = $$type{recommendedAudioCodec};
+
             if (-e "$sharedir/icons/os/$$type{id}.png") { $osver{$$type{id}}{icon} = Gtk3::Gdk::Pixbuf->new_from_file("$sharedir/icons/os/$$type{id}.png"); }
             elsif ($$type{id} =~ m/_64$/) { $osver{$$type{id}}{icon} = $gui{pb}{OtherOS64}; }
             else { $osver{$$type{id}}{icon} = $gui{pb}{OtherOS}; }
@@ -240,16 +258,18 @@ sub get_icontroller_attrs {
 
 # RDP/VNC Presets
 {
-    my @rdp_preset_tbl = ({num => 1, desc => 'FreeRDP',                    command => 'xfreerdp /size:%Xx%Y /bpp:32 +clipboard /sound /t:"%n - RemoteBox" /v:%h:%p'},
+    my @rdp_preset_tbl = ({num => 1, desc => 'FreeRDP',                    command => 'xfreerdp /size:%Xx%Y /bpp:32 +clipboard /sound /t:"%n - RemoteBox" /v:%h:%p /d: /p: /cert:ignore'},
                           {num => 2, desc => 'FreeRDP (Old Syntax)',       command => 'xfreerdp -g %Xx%Y --plugin cliprdr --plugin rdpsnd -T "%n - RemoteBox" %h:%p'},
-                          {num => 3, desc => 'Rdesktop',                   command => 'rdesktop -g %Xx%Y -r sound:local -r clipboard:PRIMARYCLIPBOARD -T "%n - RemoteBox" %h:%p'},
-                          {num => 4, desc => 'KRDC',                       command => 'krdc rdp://%h:%p'},
-                          {num => 5, desc => 'Windows RDP Client (mstsc)', command => 'mstsc /w:%X /h:%Y /v:%h:%p'});
+                          {num => 3, desc => 'Remmina',                    command => 'remmina rdp://%h:%p'},
+                          {num => 4, desc => 'Rdesktop',                   command => 'rdesktop -g %Xx%Y -r sound:local -r clipboard:PRIMARYCLIPBOARD -T "%n - RemoteBox" %h:%p -I'},
+                          {num => 5, desc => 'KRDC',                       command => 'krdc rdp://%h:%p'},
+                          {num => 6, desc => 'Windows RDP Client (mstsc)', command => 'mstsc /w:%X /h:%Y /v:%h:%p'});
 
     my @vnc_preset_tbl = ({num => 1, desc => 'TigerVNC (vncviewer)', command => 'vncviewer -Shared -AcceptClipboard -SetPrimary -SendClipboard -SendPrimary -RemoteResize -DesktopSize %Xx%Y  %h::%p'},
-                          {num => 2, desc => 'RealVNC (vncviewer)',  command => 'vncviewer -Shared -ClientCutText -SendPrimary -ServerCutText %h::%p'},
-                          {num => 3, desc => 'Vinagre',              command => 'vinagre --geometry=%Xx%Y %h::%p'},
-                          {num => 4, desc => 'KRDC',                 command => 'krdc vnc://%h:%p'});
+                          {num => 2, desc => 'Remmina',              command => 'remmina vnc://%h:%p'},
+                          {num => 3, desc => 'RealVNC (vncviewer)',  command => 'vncviewer -Shared -ClientCutText -SendPrimary -ServerCutText %h::%p'},
+                          {num => 4, desc => 'Vinagre',              command => 'vinagre --geometry=%Xx%Y %h::%p'},
+                          {num => 5, desc => 'KRDC',                 command => 'krdc vnc://%h:%p'});
 
     sub get_rdp_preset_tbl { return \@rdp_preset_tbl; }
     sub get_vnc_preset_tbl { return \@vnc_preset_tbl; }
@@ -363,4 +383,17 @@ sub strim {
     return $str;
 }
 
+sub generate_uuid {
+    my $time = int(gettimeofday * 1000000);
+    my $random = unpack('H*', pack('L*', rand(), rand(), rand(), rand()));
+    my $md5 = Digest::MD5->new;
+    $md5->add($time . $random);
+    my $digest = $md5->hexdigest;
+    return substr($digest, 0, 8) . '-' .
+           substr($digest, 8, 4) . '-' .
+           substr($digest, 12, 4) . '-' .
+           substr($digest, 16, 4) . '-' .
+           substr($digest, 20);
+}
+
 1;
