@@ -1,7 +1,6 @@
 # Main Entry for RemoteBox
 use strict;
 use warnings;
-use Data::Dumper;
 
 our (%gui, %prefs);
 my %cmdopts=();
@@ -87,14 +86,14 @@ sub virtualbox_logoff {
 
 # Fill in the fields when a profile is selected
 sub select_profile {
-    my $liststore = $gui{comboboxConnectProfile}->get_model();
-    my $iter = $gui{comboboxConnectProfile}->get_active_iter();
+    my $liststore = $gui{d}{Connect}{cboxProfile}->get_model();
+    my $iter = $gui{d}{Connect}{cboxProfile}->get_active_iter();
     my @profile = $liststore->get($iter) if (defined($iter) and $liststore->iter_is_valid($iter));
 
     if (@profile) {
-        $gui{entryConnectURL}->set_text($profile[1]);
-        $gui{entryConnectUser}->set_text($profile[2]);
-        $gui{entryConnectPassword}->set_text($profile[3]);
+        $gui{d}{Connect}{entryURL}->set_text($profile[1]);
+        $gui{d}{Connect}{entryUser}->set_text($profile[2]);
+        $gui{d}{Connect}{entryPass}->set_text($profile[3]);
     }
 }
 
@@ -104,43 +103,43 @@ sub select_profile {
 sub show_dialog_connect {
     my ($widget) = @_;
     my $response = 'cancel';
-    $gui{checkbuttonConnectSSL}->set_active($prefs{SSLVERIFY});
+    $gui{d}{Connect}{checkSSL}->set_active($prefs{SSLVERIFY});
 
     if ($widget eq 'CMDAUTO') {
-        $gui{entryConnectURL}->set_text($cmdopts{H});
-        $gui{entryConnectUser}->set_text($cmdopts{u}) if ($cmdopts{u});
-        $gui{entryConnectPassword}->set_text($cmdopts{p}) if ($cmdopts{p});
+        $gui{d}{Connect}{entryURL}->set_text($cmdopts{H});
+        $gui{d}{Connect}{entryUser}->set_text($cmdopts{u}) if ($cmdopts{u});
+        $gui{d}{Connect}{entryPass}->set_text($cmdopts{p}) if ($cmdopts{p});
         $response = 'ok';
         &addrow_msg_log("Starting automatic login (command line) to $cmdopts{H}");
     }
     elsif ($widget eq 'PROFAUTO') {
-        my $iter = $gui{liststoreProfiles}->get_iter_first();
+        my $iter = $gui{d}{Connect}{lstoreProfile}->get_iter_first();
 
-        while(defined($iter) and $gui{liststoreProfiles}->iter_is_valid($iter)) {
-            my @profile = $gui{liststoreProfiles}->get($iter);
+        while(defined($iter) and $gui{d}{Connect}{lstoreProfile}->iter_is_valid($iter)) {
+            my @profile = $gui{d}{Connect}{lstoreProfile}->get($iter);
             if ($profile[0] eq $prefs{AUTOCONNPROF}) {
-                $gui{entryConnectURL}->set_text($profile[1]);
-                $gui{entryConnectUser}->set_text($profile[2]);
-                $gui{entryConnectPassword}->set_text($profile[3]);
+                $gui{d}{Connect}{entryURL}->set_text($profile[1]);
+                $gui{d}{Connect}{entryUser}->set_text($profile[2]);
+                $gui{d}{Connect}{entryPass}->set_text($profile[3]);
                 $response = 'ok';
                 &addrow_msg_log("Starting automatic login (profile) to $profile[1]");
                 last;
             }
 
-            $gui{liststoreProfiles}->iter_next($iter); # Iter is modifed directly
+            $gui{d}{Connect}{lstoreProfile}->iter_next($iter); # Iter is modifed directly
         }
     }
     else { # Normal GUI login
-        $gui{comboboxConnectProfile}->set_active(-1); # We don't want a current active
-        $response = $gui{dialogConnect}->run;
-        $gui{dialogConnect}->hide;
+        $gui{d}{Connect}{cboxProfile}->set_active(-1); # We don't want a current active
+        $response = $gui{d}{Connect}->run;
+        $gui{d}{Connect}->hide;
     }
 
-    $gui{dialogConnect}->get_display->flush;
+    $gui{d}{Connect}->get_display->flush;
 
     if ($response eq 'ok') {
-        my $url = &strim($gui{entryConnectURL}->get_text());
-        my $user = &strim($gui{entryConnectUser}->get_text());
+        my $url = &strim($gui{d}{Connect}{entryURL}->get_text());
+        my $user = &strim($gui{d}{Connect}{entryUser}->get_text());
         $url = $endpoint if (!$url);
         $url =~ s/(\/)+$//g; # Remove all trailing
         $url = "http://$url" if ($url !~ m/^.+:\/\//);
@@ -149,7 +148,7 @@ sub show_dialog_connect {
         $prefs{USER}{$user} = 'USER' if ($user);
 
         # If we got a successful logon
-        if (&virtualbox_logon($url, $user, $gui{entryConnectPassword}->get_text())) {
+        if (&virtualbox_logon($url, $user, $gui{d}{Connect}{entryPass}->get_text())) {
             my $ver = IVirtualBox_getVersion($gui{websn});
 
             if (!$ver) {
@@ -158,10 +157,10 @@ sub show_dialog_connect {
             }
             else {
                 &addrow_msg_log("Logged into $endpoint", "Running VirtualBox $ver");
-                &show_err_msg('vboxver', "Detected VirtualBox Version: $ver") if ($ver !~ m/^7.0/);
+                &show_err_msg('vboxver', "Detected VirtualBox Version: $ver") if ($ver !~ m/^7.1/);
                 my $vhost = &vhost();
 
-                if ($$vhost{vrdeextpack} =~ m/Oracle VM VirtualBox Extension Pack/i) { $gui{toolbuttonRemoteDisplay}->set_label('_Guest Display (RDP)'); }
+                if ($$vhost{vrdeextpack} =~ m/Oracle VirtualBox Extension Pack/i) { $gui{toolbuttonRemoteDisplay}->set_label('_Guest Display (RDP)'); }
                 elsif ($$vhost{vrdeextpack} =~ m/vnc/i) {
                     $gui{toolbuttonRemoteDisplay}->set_label('_Guest Display (VNC)');
                     &addrow_msg_log('Warning: The Oracle VirtualBox Extension Pack is not installed.', '* This pack is only available for Linux, Windows, Solaris and MacOS ', '* Features which require this extension pack will be non-functional or unavailable');
@@ -186,55 +185,109 @@ sub show_dialog_connect {
     }
 }
 
+# Display a progress window for tasks which can take a long time
+sub show_progress_window {
+    my ($IProgress, $msg, $decal) = @_;
+    my $resultcode = 0;
+    my $timer = 0;
+    $decal ? $gui{d}{Progress}{img}->set_from_pixbuf($decal) : $gui{d}{Progress}{img}->set_from_pixbuf($gui{pb}{ProgressSettings});
+    $gui{d}{Progress}->set_title($msg);
+    $gui{d}{Progress}{label}->set_text('Please Wait...'); # Reset text so its not cached from a previous call
+    $gui{d}{Progress}{bar}->set_text(''); # Reset text so its not cached from a previous call
+    $gui{d}{Progress}{bar}->set_fraction(0); # Reset fraction back to 0
+    (IProgress_getCancelable($IProgress) eq 'true') ? $gui{d}{Progress}{buttonCancel}->show() : $gui{d}{Progress}{buttonCancel}->hide();
+    Gtk3::main_iteration while Gtk3::events_pending;
+
+    $timer = Glib::Timeout->add(1000,
+        sub {
+            $gui{d}{Progress}{buttonCancel}->hide() if (IProgress_getCancelable($IProgress) eq 'false'); # Sometimes cancellable earlier but not later on
+            my $percent = IProgress_getPercent($IProgress);
+            my $secsremaining = IProgress_getTimeRemaining($IProgress);
+            $gui{d}{Progress}{label}->set_text(IProgress_getOperationDescription($IProgress));
+            if (IProgress_getCompleted($IProgress) eq 'true') {
+                Glib::Source->remove($timer);
+                $timer = 0;
+                $gui{d}{Progress}{bar}->set_fraction(1.00);
+                $gui{d}{Progress}{bar}->set_text('100%');
+                $resultcode = IProgress_getResultCode($IProgress);
+                $gui{d}{Progress}->response('ok');
+                return 0;
+            }
+            else {
+
+                $gui{d}{Progress}{bar}->set_fraction($percent * 0.01);
+                if ($percent > 10 and $secsremaining > 0) {
+                    my $humantime = &secs_to_humantime($secsremaining);
+                    $gui{d}{Progress}{bar}->set_text("$percent% (About $humantime remaining)");
+                }
+                else { $gui{d}{Progress}{bar}->set_text("$percent%"); }
+                return 1;
+            }
+        });
+
+    my $response = $gui{d}{Progress}->run();
+    $gui{d}{Progress}->hide();
+    Glib::Source->remove($timer) if ($timer);
+    IProgress_cancel($IProgress) if ($response ne 'ok');
+    Gtk3::main_iteration while Gtk3::events_pending;
+    return $resultcode;
+}
+
 # Shows the about dialog
 sub show_dialog_about {
-    $gui{aboutdialog}->run;
-    $gui{aboutdialog}->hide;
+    $gui{d}{About}->run;
+    $gui{d}{About}->hide;
 }
 
 # Shows the custom video hint dialog
 sub show_dialog_videohint {
-    $gui{spinbuttonCustomVideoW}->set_value($prefs{AUTOHINTDISPX});
-    $gui{spinbuttonCustomVideoH}->set_value($prefs{AUTOHINTDISPY});
-    $gui{dialogCustomVideo}->run;
-    $gui{dialogCustomVideo}->hide;
-    return [$gui{spinbuttonCustomVideoW}->get_value_as_int(), $gui{spinbuttonCustomVideoH}->get_value_as_int(), &getsel_combo($gui{comboboxCustomVideoD}, 1)];
+    $gui{d}{CustomVideo}{sbVideoW}->set_value($prefs{AUTOHINTDISPX});
+    $gui{d}{CustomVideo}{sbVideoH}->set_value($prefs{AUTOHINTDISPY});
+    my $response = $gui{d}{CustomVideo}->run;
+    $gui{d}{CustomVideo}->hide;
+
+    if ($response eq 'ok') { return [$gui{d}{CustomVideo}{sbVideoW}->get_value_as_int(), $gui{d}{CustomVideo}{sbVideoH}->get_value_as_int(), &getsel_combo($gui{d}{CustomVideo}{cboxVideoDepth}, 1)] }
+    else { return [0,0,0]; }
 }
 
 # Shows a dialog with basic information about the VirtualBox server
 sub show_dialog_serverinfo {
     &fill_list_serverinfo();
-    $gui{dialogInfo}->set_title('Server Information');
-    $gui{dialogInfo}->run;
-    $gui{dialogInfo}->hide;
+    $gui{d}{ServerInfo}->run;
+    $gui{d}{ServerInfo}->hide;
 }
 
 # Displays a dialog with the contents of the logs for a specific guest
 sub show_dialog_log {
     my $gref = &getsel_list_guest();
     &fill_list_log($$gref{IMachine});
-    $gui{dialogLog}->set_title("$$gref{Name} Guest Logs");
-    $gui{dialogLog}->run;
-    $gui{dialogLog}->hide;
+    $gui{d}{GuestLog}->set_title("$$gref{Name} Guest Logs");
+    $gui{d}{GuestLog}->run;
+    $gui{d}{GuestLog}->hide;
+}
+
+sub refresh_guest_logs {
+    my $gref = &getsel_list_guest();
+    &fill_list_log($$gref{IMachine});
 }
 
 # Saves a guest log to a text file.
 sub guest_log_save {
     my $gref = &getsel_list_guest();
-    my $lognum = $gui{notebookLog}->get_current_page(); # We choose the log number by the page number
-    $gui{filechooserLog}->set_current_name("$$gref{Name}_log$lognum" . '.txt');
-    $gui{filechooserLog}->set_current_folder($ENV{HOME}) if ($ENV{HOME});
-    my $response = $gui{filechooserLog}->run();
-    $gui{filechooserLog}->hide();
-    my $filename = $gui{filechooserLog}->get_filename();
+    my $lognum = $gui{d}{GuestLog}{notebookLog}->get_current_page(); # We choose the log number by the page number
+    $gui{d}{LogFileChooser}->set_current_name("$$gref{Name}_log$lognum" . '.txt');
+    $gui{d}{LogFileChooser}->set_current_folder($ENV{HOME}) if ($ENV{HOME});
+    my $response = $gui{d}{LogFileChooser}->run();
+    $gui{d}{LogFileChooser}->hide();
+    my $filename = $gui{d}{LogFileChooser}->get_filename();
 
     if ($response eq 'ok' and $filename) {
         if (open(my $guest_log_fh, '>', $filename)) {
-            my $iter = $gui{'liststoreLog' . $lognum}->get_iter_first();
+            my $iter = $gui{d}{GuestLog}{'lstoreLog' . $lognum}->get_iter_first();
 
-            while (defined($iter) and $gui{'liststoreLog' . $lognum}->iter_is_valid($iter)) {
-                print $guest_log_fh $gui{'liststoreLog' . $lognum}->get($iter, 1) . "\n";
-                $gui{'liststoreLog' . $lognum}->iter_next($iter);
+            while (defined($iter) and $gui{d}{GuestLog}{'lstoreLog' . $lognum}->iter_is_valid($iter)) {
+                print $guest_log_fh $gui{d}{GuestLog}{'lstoreLog' . $lognum}->get($iter, 1) . "\n";
+                $gui{d}{GuestLog}{'lstoreLog' . $lognum}->iter_next($iter);
             }
 
             close($guest_log_fh);
@@ -246,11 +299,11 @@ sub guest_log_save {
 
 # Save the contents of the message log into a file
 sub msg_log_save {
-    $gui{filechooserLog}->set_current_name('remotebox-message-log.txt');
-    $gui{filechooserLog}->set_current_folder($ENV{HOME}) if ($ENV{HOME});
-    my $response = $gui{filechooserLog}->run();
-    $gui{filechooserLog}->hide();
-    my $filename = $gui{filechooserLog}->get_filename();
+    $gui{d}{LogFileChooser}->set_current_name('remotebox-message-log.txt');
+    $gui{d}{LogFileChooser}->set_current_folder($ENV{HOME}) if ($ENV{HOME});
+    my $response = $gui{d}{LogFileChooser}->run();
+    $gui{d}{LogFileChooser}->hide();
+    my $filename = $gui{d}{LogFileChooser}->get_filename();
 
     if($response eq 'ok' and $filename){
         if (open(my $msg_log_fh, '>', $filename)) {
@@ -273,9 +326,9 @@ sub show_dialog_exportappl {
     my $gref = &getsel_list_guest();
     my $vhost = &vhost();
     my $fname = &rcatdir($$vhost{machinedir}, $$gref{Name});
-    $gui{entryExportApplFile}->set_text($fname);
-    $gui{entryExportApplName}->set_text($$gref{Name});
-    $gui{txtbExportApplDescription}->set_text(IMachine_getDescription($$gref{IMachine}));
+    $gui{d}{ExportAppl}{entryFile}->set_text($fname);
+    $gui{d}{ExportAppl}{entryName}->set_text($$gref{Name});
+    $gui{d}{ExportAppl}{tbDescription}->set_text(IMachine_getDescription($$gref{IMachine}));
 
     # Determine if any media are USB attached as they are not supported by Appliances and
     # whether any media encrypted
@@ -303,70 +356,70 @@ sub show_dialog_exportappl {
     }
 
     do {
-        my $response = $gui{dialogExportAppl}->run;
+        my $response = $gui{d}{ExportAppl}->run();
 
         if ($response eq 'ok') {
-            if (!$gui{entryExportApplFile}->get_text()) { &show_err_msg('invalidfile'); }
-            elsif (!$gui{entryExportApplName}->get_text()) { &show_err_msg('invalidname'); }
+            if (!$gui{d}{ExportAppl}{entryFile}->get_text()) { &show_err_msg('invalidfile'); }
+            elsif (!$gui{d}{ExportAppl}{entryName}->get_text()) { &show_err_msg('invalidname'); }
             else {
-                $gui{dialogExportAppl}->hide;
-                my $location = $gui{entryExportApplFile}->get_text() . &getsel_combo($gui{comboboxExportApplFormat}, 2);
+                $gui{d}{ExportAppl}->hide;
+                my $location = $gui{d}{ExportAppl}{entryFile}->get_text() . &getsel_combo($gui{d}{ExportAppl}{cboxFormat}, 2);
                 my $IAppliance = IVirtualBox_createAppliance($gui{websn});
                 foreach my $key (keys(%used_key_ids)) { IAppliance_addPasswords($IAppliance, $key, $used_key_ids{$key}); }
                 my $IVirtualSystemDescription = IMachine_exportTo($$gref{IMachine}, $IAppliance, $location);
-                IVirtualSystemDescription_addDescription($IVirtualSystemDescription, 'Name', $gui{entryExportApplName}->get_text(), '');
-                IVirtualSystemDescription_addDescription($IVirtualSystemDescription, 'Product', $gui{entryExportApplProduct}->get_text(), '');
-                IVirtualSystemDescription_addDescription($IVirtualSystemDescription, 'ProductUrl', $gui{entryExportApplProductURL}->get_text(), '');
-                IVirtualSystemDescription_addDescription($IVirtualSystemDescription, 'Vendor', $gui{entryExportApplVendor}->get_text(), '');
-                IVirtualSystemDescription_addDescription($IVirtualSystemDescription, 'VendorUrl', $gui{entryExportApplVendorURL}->get_text(), '');
-                IVirtualSystemDescription_addDescription($IVirtualSystemDescription, 'Version', $gui{entryExportApplVersion}->get_text(), '');
-                my ($iter_s, $iter_e) = ($gui{txtbExportApplDescription}->get_start_iter(), $gui{txtbExportApplDescription}->get_end_iter());
-                IVirtualSystemDescription_addDescription($IVirtualSystemDescription, 'Description', $gui{txtbExportApplDescription}->get_text($iter_s, $iter_e, 0), '');
-                ($iter_s, $iter_e) = ($gui{txtbExportApplLicense}->get_start_iter(), $gui{txtbExportApplLicense}->get_end_iter());
-                IVirtualSystemDescription_addDescription($IVirtualSystemDescription, 'License', $gui{txtbExportApplLicense}->get_text($iter_s, $iter_e, 0), '');
+                IVirtualSystemDescription_addDescription($IVirtualSystemDescription, 'Name', $gui{d}{ExportAppl}{entryName}->get_text(), '');
+                IVirtualSystemDescription_addDescription($IVirtualSystemDescription, 'Product', $gui{d}{ExportAppl}{entryProduct}->get_text(), '');
+                IVirtualSystemDescription_addDescription($IVirtualSystemDescription, 'ProductUrl', $gui{d}{ExportAppl}{entryProductURL}->get_text(), '');
+                IVirtualSystemDescription_addDescription($IVirtualSystemDescription, 'Vendor', $gui{d}{ExportAppl}{entryVendor}->get_text(), '');
+                IVirtualSystemDescription_addDescription($IVirtualSystemDescription, 'VendorUrl', $gui{d}{ExportAppl}{entryVendorURL}->get_text(), '');
+                IVirtualSystemDescription_addDescription($IVirtualSystemDescription, 'Version', $gui{d}{ExportAppl}{entryVersion}->get_text(), '');
+                my ($iter_s, $iter_e) = ($gui{d}{ExportAppl}{tbDescription}->get_start_iter(), $gui{d}{ExportAppl}{tbDescription}->get_end_iter());
+                IVirtualSystemDescription_addDescription($IVirtualSystemDescription, 'Description', $gui{d}{ExportAppl}{tbDescription}->get_text($iter_s, $iter_e, 0), '');
+                ($iter_s, $iter_e) = ($gui{d}{ExportAppl}{tbLicense}->get_start_iter(), $gui{d}{ExportAppl}{tbLicense}->get_end_iter());
+                IVirtualSystemDescription_addDescription($IVirtualSystemDescription, 'License', $gui{d}{ExportAppl}{tbLicense}->get_text($iter_s, $iter_e, 0), '');
                 # The export options array is not at the end of the function so we have to make it a fixed size. In this case 3 elements.
                 # We also cannot pass a null option, so choose something harmless and duplicate (CreateManifest). Messy but no way around it...
                 my @exportopts = ('CreateManifest', 'CreateManifest', 'CreateManifest');
-                $exportopts[1] = 'ExportDVDImages' if ($gui{checkbuttonExportApplISO}->get_active() == 1);
-                $exportopts[2] = 'StripAllNonNATMACs' if ($gui{comboboxExportApplMAC}->get_active() == 1);
-                $exportopts[2] = 'StripAllMACs' if ($gui{comboboxExportApplMAC}->get_active() == 2);
-                my $IProgress = IAppliance_write($IAppliance, &getsel_combo($gui{comboboxExportApplFormat}, 1), @exportopts, $location);
+                $exportopts[1] = 'ExportDVDImages' if ($gui{d}{ExportAppl}{checkISO}->get_active() == 1);
+                $exportopts[2] = 'StripAllNonNATMACs' if ($gui{d}{ExportAppl}{cboxMAC}->get_active() == 1);
+                $exportopts[2] = 'StripAllMACs' if ($gui{d}{ExportAppl}{cboxMAC}->get_active() == 2);
+                my $IProgress = IAppliance_write($IAppliance, &getsel_combo($gui{d}{ExportAppl}{cboxFormat}, 1), @exportopts, $location);
                 if ($IProgress) { &show_progress_window($IProgress, "Exporting Appliance $$gref{Name}", $gui{pb}{ProgressExport}); }
                 &addrow_msg_log("Exported $$gref{Name} as an appliance to $location");
             }
         }
-        else { $gui{dialogExportAppl}->hide; }
+        else { $gui{d}{ExportAppl}->hide; }
 
-    } until (!$gui{dialogExportAppl}->get_visible());
+    } until (!$gui{d}{ExportAppl}->get_visible());
 }
 
 sub show_dialog_snap_details {
     my $snapref = &getsel_list_snapshots();
 
     if ($$snapref{ISnapshot}) { # This is needed in case a user double clicks on "Current State" which is not a real snapshot
-        $gui{entrySnapshotName}->set_text(ISnapshot_getName($$snapref{ISnapshot}));
-        $gui{txtbSnapshotDescription}->set_text(ISnapshot_getDescription($$snapref{ISnapshot}));
-        my $response = $gui{dialogSnapshot}->run;
-        $gui{dialogSnapshot}->hide;
+        $gui{d}{Snapshot}{Name}->set_text(ISnapshot_getName($$snapref{ISnapshot}));
+        $gui{d}{Snapshot}{tbDescription}->set_text(ISnapshot_getDescription($$snapref{ISnapshot}));
+        my $response = $gui{d}{Snapshot}->run;
+        $gui{d}{Snapshot}->hide;
 
         if ($response eq 'ok') {
-            my ($iter_s, $iter_e) = ($gui{txtbSnapshotDescription}->get_start_iter(), $gui{txtbSnapshotDescription}->get_end_iter());
-            ISnapshot_setDescription($$snapref{ISnapshot}, $gui{txtbSnapshotDescription}->get_text($iter_s, $iter_e, 0));
-            ISnapshot_setName($$snapref{ISnapshot}, $gui{entrySnapshotName}->get_text());
+            my ($iter_s, $iter_e) = ($gui{d}{Snapshot}{tbDescription}->get_start_iter(), $gui{d}{Snapshot}{tbDescription}->get_end_iter());
+            ISnapshot_setDescription($$snapref{ISnapshot}, $gui{d}{Snapshot}{tbDescription}->get_text($iter_s, $iter_e, 0));
+            ISnapshot_setName($$snapref{ISnapshot}, $gui{d}{Snapshot}{Name}->get_text());
             &fill_list_guest();
         }
     }
 }
 
 sub show_dialog_snapshot {
-    $gui{entrySnapshotName}->set_text('Snapshot');
-    $gui{txtbSnapshotDescription}->set_text('');
-    my $response = $gui{dialogSnapshot}->run();
-    $gui{dialogSnapshot}->hide();
+    $gui{d}{Snapshot}{Name}->set_text('Snapshot');
+    $gui{d}{Snapshot}{tbDescription}->set_text('');
+    my $response = $gui{d}{Snapshot}->run();
+    $gui{d}{Snapshot}->hide();
 
     if ($response eq 'ok') {
-        my ($iter_s, $iter_e) = ($gui{txtbSnapshotDescription}->get_start_iter(), $gui{txtbSnapshotDescription}->get_end_iter());
-        &take_snapshot($gui{entrySnapshotName}->get_text(), $gui{txtbSnapshotDescription}->get_text($iter_s, $iter_e, 0));
+        my ($iter_s, $iter_e) = ($gui{d}{Snapshot}{tbDescription}->get_start_iter(), $gui{d}{Snapshot}{tbDescription}->get_end_iter());
+        &take_snapshot($gui{d}{Snapshot}{Name}->get_text(), $gui{d}{Snapshot}{tbDescription}->get_text($iter_s, $iter_e, 0));
     }
 }
 
@@ -491,7 +544,7 @@ sub start_guest {
     if ($IProgress) { # Is Cancellable
         my $resultcode = &show_progress_window($IProgress, "Starting guest $$gref{Name}", $gui{pb}{ProgressStart});
 
-        if (IProgress_getCanceled($IProgress) eq 'true') { &addrow_msg_log("tarting guest $$gref{Name} cancelled"); }
+        if (IProgress_getCanceled($IProgress) eq 'true') { &addrow_msg_log("Starting guest $$gref{Name} cancelled"); }
         elsif ($resultcode != 0) {
             my $IVirtualBoxErrorInfo = IProgress_getErrorInfo($IProgress);
             &show_err_msg('startguest', "Guest: $$gref{Name}\nCode: $resultcode\nError:\n" . IVirtualBoxErrorInfo_getText($IVirtualBoxErrorInfo));
@@ -517,7 +570,7 @@ sub start_guest {
 
                             if ($$sref{Lock} eq 'Shared') {
                                 my $IConsole = ISession_getConsole($$sref{ISession});
-                                IConsole_addDiskEncryptionPassword($IConsole, $keyid, $passwd, 0);
+                                IConsole_addEncryptionPassword($IConsole, $keyid, $passwd, 0);
                             }
 
                             ISession_unlockMachine($$sref{ISession}) if (ISession_getState($$sref{ISession}) eq 'Locked');
@@ -542,8 +595,8 @@ sub start_guest {
 # Removes a guest, optionally deleting associated files
 sub remove_guest {
     my $gref = &getsel_list_guest();
-    my $response = $gui{dialogRemoveGuest}->run;
-    $gui{dialogRemoveGuest}->hide;
+    my $response = $gui{d}{RemoveGuest}->run();
+    $gui{d}{RemoveGuest}->hide;
 
     if ($response eq '1') { # Remove Only
         IMachine_unregister($$gref{IMachine}, 'DetachAllReturnNone');
@@ -650,7 +703,7 @@ sub open_remote_display {
 
             my $dst = $bindaddress ? $bindaddress : $endpoint; # If there's a specific bind address for the guest use that
             my $dispcmd = ($$vhost{vrdeextpack} =~ m/vnc/i) ? $prefs{VNCCLIENT} : $prefs{RDPCLIENT};
-            my ($user, $pass) = ($gui{entryConnectUser}->get_text(), $gui{entryConnectPassword}->get_text());
+            my ($user, $pass) = ($gui{d}{Connect}{entryUser}->get_text(), $gui{d}{Connect}{entryPass}->get_text());
             $dst =~ s/^.*:\/\///;
             $dst =~ s/:\d+$//;
             $dispcmd =~ s/%h/$dst/g;
@@ -944,10 +997,10 @@ sub keyboard_send {
 
 # Updates the video memory requirement when choosing a custom video hint
 sub update_vidmeminfo {
-    my $w = $gui{spinbuttonCustomVideoW}->get_value_as_int();
-    my $h = $gui{spinbuttonCustomVideoH}->get_value_as_int();
-    my $d = &getsel_combo($gui{comboboxCustomVideoD}, 1);
-    $gui{labelCustomVideoInfo}->set_text('This resolution requires a minimum of ' . &vram_needed($w, $h, $d) . 'MB of video memory');
+    my $w = $gui{d}{CustomVideo}{sbVideoW}->get_value_as_int();
+    my $h = $gui{d}{CustomVideo}{sbVideoH}->get_value_as_int();
+    my $d = &getsel_combo($gui{d}{CustomVideo}{cboxVideoDepth}, 1);
+    $gui{d}{CustomVideo}{labelVideoInfo}->set_text('This resolution requires a minimum of ' . &vram_needed($w, $h, $d) . 'MB of video memory');
 }
 
 # Sends a video mode hint to the guest
@@ -958,10 +1011,13 @@ sub send_video_hint {
 
     if ($widget eq $gui{miSetVideoCustom}) { $res = &show_dialog_videohint(); }
 
-    if ($$sref{IMachine}) {
-        my $IConsole = ISession_getConsole($$sref{ISession});
-        IDisplay_setVideoModeHint(IConsole_getDisplay($IConsole), 0, 1, 0, 0, 0, $$res[0], $$res[1], $$res[2], 1);
-        &addrow_msg_log("Video hint ($$res[0]x$$res[1]:$$res[2]) sent to $$gref{Name}");
+    # This checks if the custom res window got cancels as the resolution will be 0
+    if ($$res[0] > 0) {
+        if ($$sref{IMachine}) {
+            my $IConsole = ISession_getConsole($$sref{ISession});
+            IDisplay_setVideoModeHint(IConsole_getDisplay($IConsole), 0, 1, 0, 0, 0, $$res[0], $$res[1], $$res[2], 1);
+            &addrow_msg_log("Video hint ($$res[0]x$$res[1]:$$res[2]) sent to $$gref{Name}");
+        }
     }
 
     ISession_unlockMachine($$sref{ISession}) if (ISession_getState($$sref{ISession}) eq 'Locked');
@@ -1103,11 +1159,11 @@ sub reset_icon {
 sub screenshot {
     my $gref = &getsel_list_guest();
     my $sref = &get_session($$gref{IMachine});
-    $gui{filechooserscreenshot}->set_current_name("$$gref{Name}_screenshot.png");
-    $gui{filechooserscreenshot}->set_current_folder($ENV{HOME}) if ($ENV{HOME});
-    my $response = $gui{filechooserscreenshot}->run();
-    $gui{filechooserscreenshot}->hide();
-    my $filename = $gui{filechooserscreenshot}->get_filename();
+    $gui{d}{ScreenShotFileChooser}->set_current_name("$$gref{Name}_screenshot.png");
+    $gui{d}{ScreenShotFileChooser}->set_current_folder($ENV{HOME}) if ($ENV{HOME});
+    my $response = $gui{d}{ScreenShotFileChooser}->run();
+    $gui{d}{ScreenShotFileChooser}->hide();
+    my $filename = $gui{d}{ScreenShotFileChooser}->get_filename();
 
     if ($response eq 'ok' and $filename) {
         if ($$sref{Lock} eq 'Shared') {
@@ -1174,21 +1230,21 @@ sub group_list_collapse {
 # Shows the dialog for importing an appliance
 sub show_dialog_importappl {
     my $vhost = &vhost();
-    $gui{entryImportApplFile}->set_text(&rcatfile($$vhost{machinedir}, 'appliance.ova'));
+    $gui{d}{ImportAppl}{entryAppl}->set_text(&rcatfile($$vhost{machinedir}, 'appliance.ova'));
 
     do {
-        my $response = $gui{dialogImportAppl}->run;
+        my $response = $gui{d}{ImportAppl}->run();
 
         if ($response eq 'ok') {
             my @importopts;
             push (@importopts, 'ImportToVDI') if ($gui{checkbuttonImportApplToVDI}->get_active() == 1);
-            push (@importopts, 'KeepAllMACs') if ($gui{comboboxImportApplMAC}->get_active() == 0);
-            push (@importopts, 'KeepNATMACs') if ($gui{comboboxImportApplMAC}->get_active() == 1);
+            push (@importopts, 'KeepAllMACs') if ($gui{d}{ImportAppl}{cboxMAC}->get_active() == 0);
+            push (@importopts, 'KeepNATMACs') if ($gui{d}{ImportAppl}{cboxMAC}->get_active() == 1);
 
-            if (!$gui{entryImportApplFile}->get_text()) { &show_err_msg('invalidfile'); }
+            if (!$gui{d}{ImportAppl}{entryAppl}->get_text()) { &show_err_msg('invalidfile'); }
             else {
-                $gui{dialogImportAppl}->hide;
-                my $appliancefile = $gui{entryImportApplFile}->get_text();
+                $gui{d}{ImportAppl}->hide;
+                my $appliancefile = $gui{d}{ImportAppl}{entryAppl}->get_text();
                 &addrow_msg_log("Importing appliance from $appliancefile");
                 my $IAppliance = IVirtualBox_createAppliance($gui{websn});
                 my $IProgress = IAppliance_read($IAppliance, $appliancefile);
@@ -1215,20 +1271,20 @@ sub show_dialog_importappl {
                 else { &show_err_msg('applimport', "\nAppliance: $appliancefile"); }
             }
         }
-        else { $gui{dialogImportAppl}->hide; }
+        else { $gui{d}{ImportAppl}->hide; }
 
-    } until (!$gui{dialogImportAppl}->get_visible());
+    } until (!$gui{d}{ImportAppl}->get_visible());
 }
 
 # Displays the dialog for entering a decryption password
 sub show_dialog_decpasswd {
     my ($IMedium, $keyid) = @_;
     my $passwd;
-    $gui{labelEnterDecPasswdID}->set_text("Key ID: $keyid");
-    $gui{labelEnterDecPasswdName}->set_text("Disk Name: " . IMedium_getName($IMedium));
-    my $response = $gui{dialogEnterDecPasswd}->run;
-    $gui{dialogEnterDecPasswd}->hide;
-    if ($response eq 'ok') { $passwd = $gui{entryEnterDecPasswd}->get_text(); }
+    $gui{d}{DecPassword}{labelKeyID}->set_text($keyid);
+    $gui{d}{DecPassword}{labelDisk}->set_text(IMedium_getName($IMedium));
+    my $response = $gui{d}{DecPassword}->run;
+    $gui{d}{DecPassword}->hide;
+    if ($response eq 'ok') { $passwd = $gui{d}{DecPassword}{entryPass}->get_text(); }
     return $passwd;
 }
 
@@ -1239,12 +1295,12 @@ sub show_dialog_group {
 
     if ($$sref{Lock} ne 'None') {
         my ($group) = IMachine_getGroups($$sref{IMachine}, ('/')); # Only interested in first group entry
-        $gui{entrySetGroupGroup}->set_text($group);
-        my $response = $gui{dialogSetGroup}->run;
-        $gui{dialogSetGroup}->hide;
+        $gui{d}{SetGroup}{entryGroup}->set_text($group);
+        my $response = $gui{d}{SetGroup}->run();
+        $gui{d}{SetGroup}->hide;
 
         if ($response eq 'ok') {
-            $group = $gui{entrySetGroupGroup}->get_text();
+            $group = $gui{d}{SetGroup}{entryGroup}->get_text();
             $group =~ s/\/+$//; # Remove any trailing slashes
             $group = "/$group" if ($group !~ m/^\//);
             IMachine_setGroups($$sref{IMachine}, ($group));
@@ -1292,7 +1348,7 @@ sub extended_details {
 }
 
 sub set_connection_prof_inactive {
-    $gui{comboboxConnectProfile}->set_active(-1);
+    $gui{d}{Connect}{cboxProfile}->set_active(-1);
 }
 
 1;
