@@ -6,70 +6,76 @@ our (%gui, %signal, %prefs);
 sub show_dialog_new_guest {
     my $vhost = &vhost();
     my ($osfam, $osver) = &osfamver();
-    $gui{checkbuttonNewNewHD}->set_active(1);
-    $gui{comboboxNewNewFormat}->set_active(0);
-    $gui{radiobuttonNewDynamic}->set_sensitive(1);
-    $gui{radiobuttonNewFixed}->set_sensitive(1);
-    $gui{radiobuttonNewSplit}->set_sensitive(0);
-    $gui{entryNewName}->set_text('Guest-' . int(rand(999999)));
-    $gui{spinbuttonNewMemory}->set_range($$vhost{minguestram}, $$vhost{memsize});
-    $gui{spinbuttonNewNewHDSize}->set_range($$vhost{minhdsizemb}, $$vhost{maxhdsizemb});
-    $gui{comboboxNewOSFam}->signal_handler_block($signal{comboboxNewOSFam_changed}); # Block to avoid signal emission when changing
-    $gui{comboboxNewOSVer}->signal_handler_block($signal{comboboxNewOSVer_changed});
-    $gui{liststoreNewOSFam}->clear();
-    $gui{liststoreNewOSVer}->clear();
-    $gui{liststoreNewChooseHD}->clear();
+    $gui{d}{New}{checkStartupDisk}->set_active(1);
+    $gui{d}{New}{cboxFormat}->set_active(0);
+    $gui{d}{New}{radioDynamic}->set_sensitive(1);
+    $gui{d}{New}{radioFixed}->set_sensitive(1);
+    $gui{d}{New}{radioSplit}->set_sensitive(0);
+    $gui{d}{New}{entryName}->set_text('Guest-' . int(rand(999999)));
+    $gui{d}{New}{sbMemory}->set_range($$vhost{minguestram}, $$vhost{memsize});
+    $gui{d}{New}{sbSize}->set_range($$vhost{minhdsizemb}, $$vhost{maxhdsizemb});
+    $gui{d}{New}{scaleMemory}->clear_marks();
+    $gui{d}{New}{scaleMemory}->add_mark(262144.00,'GTK_POS_BOTTOM') if (262144 <= $$vhost{memsize});
+    $gui{d}{New}{scaleMemory}->add_mark(131072.00,'GTK_POS_TOP') if (131072 <= $$vhost{memsize});
+    $gui{d}{New}{scaleMemory}->add_mark(65536.00,'GTK_POS_BOTTOM') if (65536 <= $$vhost{memsize});
+    $gui{d}{New}{scaleMemory}->add_mark(32768.00,'GTK_POS_TOP') if (32768 <= $$vhost{memsize});
+    $gui{d}{New}{scaleMemory}->add_mark(16384.00,'GTK_POS_BOTTOM') if (16384 <= $$vhost{memsize});
+    $gui{d}{New}{scaleMemory}->add_mark(8192.00,'GTK_POS_TOP') if (8192 <= $$vhost{memsize});
+    $gui{d}{New}{scaleMemory}->add_mark(4096.00,'GTK_POS_BOTTOM') if (4096 <= $$vhost{memsize});
+    $gui{d}{New}{scaleMemory}->add_mark(2048.00,'GTK_POS_TOP') if (2048 <= $$vhost{memsize});
+    $gui{d}{New}{scaleMemory}->add_mark(1024.00,'GTK_POS_BOTTOM') if (1024 <= $$vhost{memsize});
+    $gui{d}{New}{cboxFamily}->signal_handler_block($signal{New_cboxFamily_changed}); # Block to avoid signal emission when changing
+    $gui{d}{New}{cboxVersion}->signal_handler_block($signal{New_cboxVersion_changed});
+    $gui{d}{New}{lstoreFamily}->clear();
+    $gui{d}{New}{lstoreVersion}->clear();
+    $gui{d}{New}{lstoreExistingDisk}->clear();
 
-    foreach my $fam (sort {
-                            if    ($$osfam{$a}{description} =~ m/Other/) { return 1; }
+    foreach my $fam (sort { if    ($$osfam{$a}{description} =~ m/Other/) { return 1; }
                             elsif ($$osfam{$b}{description} =~ m/Other/) { return -1; }
                             else  { return lc($$osfam{$a}{description}) cmp lc($$osfam{$b}{description}) }
                           } keys %{$osfam}) {
 
-        my $iter = $gui{liststoreNewOSFam}->append();
-        $gui{liststoreNewOSFam}->set($iter, [0, 1, 2], ["$$osfam{$fam}{description}", $fam, $$osfam{$fam}{icon}]);
-        $gui{comboboxNewOSFam}->set_active_iter($iter) if ($fam eq 'Windows');
+        my $iter = $gui{d}{New}{lstoreFamily}->append();
+        $gui{d}{New}{lstoreFamily}->set($iter, [0, 1, 2], ["$$osfam{$fam}{description}", $fam, $$osfam{$fam}{icon}]);
+        $gui{d}{New}{cboxFamily}->set_active_iter($iter) if ($fam eq 'Windows');
     }
 
     my $IMediumRef = &get_all_media('HardDisk');
 
     if (keys(%$IMediumRef) > 0) {
         foreach my $hd (sort { lc($$IMediumRef{$a}) cmp lc($$IMediumRef{$b}) } (keys(%$IMediumRef))) {
-            my $iter = $gui{liststoreNewChooseHD}->append();
-            $gui{liststoreNewChooseHD}->set($iter, [0, 1], [$$IMediumRef{$hd}, $hd]);
+            my $iter = $gui{d}{New}{lstoreExistingDisk}->append();
+            $gui{d}{New}{lstoreExistingDisk}->set($iter, [0, 1], [$$IMediumRef{$hd}, $hd]);
         }
 
-        $gui{comboboxNewChooseHD}->set_active(0);
-        $gui{radiobuttonNewExistingHD}->set_sensitive(1);
+        $gui{d}{New}{cboxExistingDisk}->set_active(0);
+        $gui{d}{New}{radioExistingDisk}->set_sensitive(1);
     }
-    else { $gui{radiobuttonNewExistingHD}->set_sensitive(0); };
+    else { $gui{d}{New}{radioExistingDisk}->set_sensitive(0); };
 
-    $gui{comboboxNewOSFam}->signal_handler_unblock($signal{comboboxNewOSFam_changed});
-    $gui{comboboxNewOSVer}->signal_handler_unblock($signal{comboboxNewOSVer_changed});
-    $gui{comboboxNewOSFam}->signal_emit('changed'); # Force update of other fields based on OS
-    $gui{comboboxNewOSVer}->signal_emit('changed'); # Force update of other fields based on OS
+    $gui{d}{New}{cboxFamily}->signal_handler_unblock($signal{New_cboxFamily_changed});
+    $gui{d}{New}{cboxVersion}->signal_handler_unblock($signal{New_cboxVersion_changed});
+    $gui{d}{New}{cboxFamily}->signal_emit('changed'); # Force update of other fields based on OS
+    $gui{d}{New}{cboxVersion}->signal_emit('changed'); # Force update of other fields based on OS
     &fill_list_new_guest_dvd();
 
     do {
-        my $response = $gui{dialogNew}->run;
+        my $response = $gui{d}{New}->run;
 
         if ($response eq 'ok') {
             # Other entries do not require validation
-            if (!$gui{entryNewName}->get_text()) { &show_err_msg('invalidname'); }
+            if (!$gui{d}{New}{entryName}->get_text()) { &show_err_msg('invalidname'); }
             else {
-                $gui{dialogNew}->hide;
-
-                my $name = $gui{entryNewName}->get_text();
-                my $IMachine = IVirtualBox_createMachine($gui{websn}, '', $name, '', &getsel_combo($gui{comboboxNewOSVer}, 1), 'UUID 00000000-0000-0000-0000-000000000000', '');
+                $gui{d}{New}->hide();
+                my $name = $gui{d}{New}{entryName}->get_text();
+                my $IMachine = IVirtualBox_createMachine($gui{websn}, '', $name, &getsel_combo($gui{d}{New}{cboxVersion}, 2), '', &getsel_combo($gui{d}{New}{cboxVersion}, 1), 'UUID=' . &generate_uuid(), '');
 
                 if ($IMachine) {
                     IMachine_applyDefaults($IMachine);
-                    IMachine_setMemorySize($IMachine, $gui{spinbuttonNewMemory}->get_value_as_int());
-                    my $IAudioSettings = IMachine_getAudioSettings($IMachine);
-                    my $IAudioAdapter = IAudioSettings_getAdapter($IAudioSettings);
-                    IAudioAdapter_setAudioDriver($IAudioAdapter, 'Null');
+                    IMachine_saveSettings($IMachine); # Seems to be needed here to work around a VB bug, where it doesn't enable the VRDE server.
+                    IMachine_setMemorySize($IMachine, $gui{d}{New}{sbMemory}->get_value_as_int());
+                    IAudioAdapter_setAudioDriver(IAudioSettings_getAdapter(IMachine_getAudioSettings($IMachine)), 'Null');
                     my $IVRDEServer = IMachine_getVRDEServer($IMachine);
-                    IVRDEServer_setVRDEProperty($IVRDEServer, 'VideoChannel/Quality', 75);
                     IVRDEServer_setEnabled($IVRDEServer, 'true');
                     IVRDEServer_setAllowMultiConnection($IVRDEServer, 'true');
                     IMachine_setClipboardMode($IMachine, 'Bidirectional');
@@ -83,26 +89,26 @@ sub show_dialog_new_guest {
                     my $sref = &get_session($IMachine);
 
                     if ($$sref{Type} eq 'WriteLock') {
-                        # Hard Disk Section
-                        if ($gui{checkbuttonNewNewHD}->get_active() == 1) {
+
+                        if ($gui{d}{New}{checkStartupDisk}->get_active() == 1) {
                             my $IMediumHD;
 
-                            if ($gui{radiobuttonNewNewHD}->get_active()) {
+                            if ($gui{d}{New}{radioNewDisk}->get_active()) {
                                 my %newhd = (diskname   => $name, # Use guest name as basis for disk
-                                            devicetype => 'HardDisk',
-                                            mode       => 'ReadWrite',
-                                            size       => $gui{spinbuttonNewNewHDSize}->get_value_as_int() * 1048576,
-                                            allocation => ['Standard'], # Standard == Dynamic Allocation
-                                            imgformat  => &getsel_combo($gui{comboboxNewNewFormat}, 1),
-                                            location   => &rcatdir($$vhost{machinedir}, $name));
+                                             devicetype => 'HardDisk',
+                                             mode       => 'ReadWrite',
+                                             size       => $gui{d}{New}{sbSize}->get_value_as_int() * 1048576,
+                                             allocation => ['Standard'], # Standard == Dynamic Allocation
+                                             imgformat  => &getsel_combo($gui{d}{New}{cboxFormat}, 1),
+                                             location   => &rcatdir($$vhost{machinedir}, $name));
 
-                                if ($gui{radiobuttonNewFixed}->get_active()) { $newhd{allocation} = ['Fixed']; }
-                                elsif ($gui{radiobuttonNewSplit}->get_active()) { $newhd{allocation} = ['VmdkSplit2G']; }
+                                if ($gui{d}{New}{radioFixed}->get_active()) { $newhd{allocation} = ['Fixed']; }
+                                elsif ($gui{d}{New}{radioSplit}->get_active()) { $newhd{allocation} = ['VmdkSplit2G']; }
                                 $IMediumHD = &create_new_dskimg(\%newhd);
                             }
-                            else { $IMediumHD = &getsel_combo($gui{comboboxNewChooseHD}, 1); }
+                            else { $IMediumHD = &getsel_combo($gui{d}{New}{cboxExistingDisk}, 1); }
 
-                            my %os = %{ $$osver{&getsel_combo($gui{comboboxNewOSVer}, 1)} };
+                            my %os = %{ $$osver{&getsel_combo($gui{d}{New}{cboxVersion}, 1)} };
                             my $IStorCtrHD = IMachine_getStorageControllerByInstance($$sref{IMachine}, $os{recommendedHDStorageBus}, 0);
                             my %hdaddress = &get_free_deviceport($$sref{IMachine}, $IStorCtrHD);
                             IMachine_attachDevice($$sref{IMachine}, $os{recommendedHDStorageBus}, $hdaddress{portnum}, $hdaddress{devnum}, 'HardDisk', $IMediumHD) if ($IMediumHD);
@@ -118,7 +124,7 @@ sub show_dialog_new_guest {
                         }
 
                         # ISO Section
-                        my $IMediumDVD = &getsel_combo($gui{comboboxNewISOImage}, 1);
+                        my $IMediumDVD = &getsel_combo($gui{d}{New}{cboxISO}, 1);
                         if (defined($IMediumDVD)) {
                             my @IMediumAttachment = IMachine_getMediumAttachments($$sref{IMachine});
                             foreach my $attach (@IMediumAttachment) {
@@ -137,49 +143,50 @@ sub show_dialog_new_guest {
                 else { &show_err_msg('createguest', " ($name)"); }
             }
         }
-        else { $gui{dialogNew}->hide; }
+        else { $gui{d}{New}->hide; }
 
-    } until (!$gui{dialogNew}->get_visible());
+    } until (!$gui{d}{New}->get_visible());
 }
 
 # Shows the dialog for creating a new clone
-sub show_dialog_clone {
+sub show_dialogClone {
     my $gref = &getsel_list_guest();
-    $gui{entryCloneName}->set_text($$gref{Name} . '-Clone-' . int(rand(999999)));
+    $gui{d}{Clone}{entryName}->set_text($$gref{Name} . '-Clone-' . int(rand(999999)));
 
     do {
-        my $response = $gui{dialogClone}->run;
+        $gui{d}{Clone}->show_all;
+        my $response = $gui{d}{Clone}->run();
 
         if ($response eq 'ok') {
             # No validation needed for other entries
-            if (!$gui{entryCloneName}->get_text()) { &show_err_msg('invalidname'); }
+            if (!$gui{d}{Clone}{entryName}->get_text()) { &show_err_msg('invalidname'); }
             else {
-                $gui{dialogClone}->hide;
+                $gui{d}{Clone}->hide;
 
-                my %newclone = (name    => $gui{entryCloneName}->get_text(),
+                my %newclone = (name    => $gui{d}{Clone}{entryName}->get_text(),
                                 mode    => 'MachineState',
                                 linked  => 0,
                                 options => []);
 
                 # All other clone types just use 'MachineState'
-                $newclone{mode} = 'AllStates' if ($gui{comboboxCloneType}->get_active() == 0);
+                $newclone{mode} = 'AllStates' if ($gui{d}{Clone}{cboxType}->get_active() == 0);
 
                 # The Link type is not really a mode, but an option
-                if ($gui{comboboxCloneType}->get_active() == 2) {
+                if ($gui{d}{Clone}{cboxType}->get_active() == 2) {
                     push(@{$newclone{options}}, 'Link');
                     $newclone{linked} = 1;
                 }
-                push(@{$newclone{options}}, 'KeepAllMACs') if ($gui{comboboxCloneMAC}->get_active() == 0); # New MACs are generated by default
-                push(@{$newclone{options}}, 'KeepNATMACs') if ($gui{comboboxCloneMAC}->get_active() == 1); # New MACs are generated by default
-                push(@{$newclone{options}}, 'KeepDiskNames') if ($gui{checkbuttonCloneKeepDiskNames}->get_active() == 1);
-                push(@{$newclone{options}}, 'KeepHwUUIDs') if ($gui{checkbuttonCloneKeepHardwareUUIDs}->get_active() == 1);
+                push(@{$newclone{options}}, 'KeepAllMACs') if ($gui{d}{Clone}{cboxMAC}->get_active() == 0); # New MACs are generated by default
+                push(@{$newclone{options}}, 'KeepNATMACs') if ($gui{d}{Clone}{cboxMAC}->get_active() == 1); # New MACs are generated by default
+                push(@{$newclone{options}}, 'KeepDiskNames') if ($gui{d}{Clone}{checkKeepDiskName}->get_active() == 1);
+                push(@{$newclone{options}}, 'KeepHwUUIDs') if ($gui{d}{Clone}{checkKeepUUIDs}->get_active() == 1);
                 &create_new_clone($gref, \%newclone);
                 &fill_list_guest();
             }
         }
-        else { $gui{dialogClone}->hide; }
+        else { $gui{d}{Clone}->hide; }
 
-    } until (!$gui{dialogClone}->get_visible());
+    } until (!$gui{d}{Clone}->get_visible());
 }
 
 # Determines the next free port number and device number on a controller. If
@@ -233,7 +240,7 @@ sub create_new_clone {
     my $vhost = &vhost();
     my ($srcgref, $cloneref) = @_;
     # We create a new 'empty' guest
-    my $cloneIMachine = IVirtualBox_createMachine($gui{websn}, '', $$cloneref{name}, '', $$srcgref{Osid}, 'UUID 00000000-0000-0000-0000-000000000000', '');
+    my $cloneIMachine = IVirtualBox_createMachine($gui{websn}, '', $$cloneref{name}, 'x86', '', $$srcgref{Osid}, &generate_uuid(), '');
     my $IProgress;
 
     if ($$cloneref{linked}) { # Is cancellable
@@ -319,20 +326,20 @@ sub newgen_osfam {
     my ($combofam, $combover) = @_;
     my ($osfam, $osver) = &osfamver();
     my $fam = &getsel_combo($combofam, 1);
-    $combofam->signal_handler_block($signal{comboboxNewOSFam_changed}); # Block to avoid signal emission when changing
-    $combover->signal_handler_block($signal{comboboxNewOSVer_changed});
-    $gui{liststoreNewOSVer}->clear();
+    $combofam->signal_handler_block($signal{New_cboxFamily_changed}); # Block to avoid signal emission when changing
+    $combover->signal_handler_block($signal{New_cboxVersion_changed});
+    $gui{d}{New}{lstoreVersion}->clear();
 
     foreach my $ver (@{ $$osfam{$fam}{verids} })
     {
-        my $iter = $gui{liststoreNewOSVer}->append();
-        $gui{liststoreNewOSVer}->set($iter, [0, 1, 2], [$$osver{$ver}{description}, $ver, $$osver{$ver}{icon}]);
+        my $iter = $gui{d}{New}{lstoreVersion}->append();
+        $gui{d}{New}{lstoreVersion}->set($iter, [0, 1, 2, 3], [$$osver{$ver}{description}, $ver, $$osver{$ver}{platformArchitecture}, $$osver{$ver}{icon}]);
         $combover->set_active_iter($iter) if ($ver eq 'Windows10_64' | $ver eq 'Fedora_64' | $ver eq 'Solaris11_64' | $ver eq 'FreeBSD_64' | $ver eq 'DOS');
     }
 
     $combover->set_active(0) if ($combover->get_active() == -1);
-    $combofam->signal_handler_unblock($signal{comboboxNewOSFam_changed});
-    $combover->signal_handler_unblock($signal{comboboxNewOSVer_changed});
+    $combofam->signal_handler_unblock($signal{New_cboxFamily_changed});
+    $combover->signal_handler_unblock($signal{New_cboxVersion_changed});
     $combover->signal_emit('changed'); # Force update of other fields based on OS
 }
 
@@ -340,12 +347,12 @@ sub newgen_osver {
     my ($combover, $combofam) = @_;
     my $osver = &osver();
     my $ver = &getsel_combo($combover, 1);
-    $combofam->signal_handler_block($signal{comboboxNewOSFam_changed}); # Avoid signal emission when changing
-    $combover->signal_handler_block($signal{comboboxNewOSVer_changed});
-    $gui{spinbuttonNewMemory}->set_value($$osver{$ver}{recommendedRAM});
-    $gui{spinbuttonNewNewHDSize}->set_value($$osver{$ver}{recommendedHDD} / 1048576);
-    $combofam->signal_handler_unblock($signal{comboboxNewOSFam_changed});
-    $combover->signal_handler_unblock($signal{comboboxNewOSVer_changed});
+    $combofam->signal_handler_block($signal{New_cboxFamily_changed}); # Avoid signal emission when changing
+    $combover->signal_handler_block($signal{New_cboxVersion_changed});
+    $gui{d}{New}{sbMemory}->set_value($$osver{$ver}{recommendedRAM});
+    $gui{d}{New}{sbSize}->set_value($$osver{$ver}{recommendedHDD} / 1048576);
+    $combofam->signal_handler_unblock($signal{New_cboxFamily_changed});
+    $combover->signal_handler_unblock($signal{New_cboxVersion_changed});
 }
 
 sub newstor_new_exist {
@@ -353,57 +360,57 @@ sub newstor_new_exist {
     my $buttongrp = $widget->get_group();
 
     if ($$buttongrp[0]->get_active() == 1) {
-        $gui{comboboxNewChooseHD}->set_sensitive(1); # This is use an existing HD
-        $gui{tableNewNewHD}->set_sensitive(0);
+        $gui{d}{New}{cboxExistingDisk}->set_sensitive(1); # This is use an existing HD
+        $gui{d}{New}{HD}->set_sensitive(0);
     }
     else {
-        $gui{comboboxNewChooseHD}->set_sensitive(0); # This is creating a new HD
-        $gui{tableNewNewHD}->set_sensitive(1);
+        $gui{d}{New}{cboxExistingDisk}->set_sensitive(0); # This is creating a new HD
+        $gui{d}{New}{HD}->set_sensitive(1);
     }
 }
 
 # Handle the toggle startup disk selection
 sub toggle_newstartupdisk {
-    if ($gui{checkbuttonNewNewHD}->get_active() == 1) {
-        $gui{radiobuttonNewNewHD}->show();
-        $gui{radiobuttonNewExistingHD}->show();
-        $gui{tableNewNewHD}->show();
-        $gui{comboboxNewChooseHD}->show();
+    if ($gui{d}{New}{checkStartupDisk}->get_active() == 1) {
+        $gui{d}{New}{radioNewDisk}->show();
+        $gui{d}{New}{radioExistingDisk}->show();
+        $gui{d}{New}{HD}->show();
+        $gui{d}{New}{cboxExistingDisk}->show();
     }
     else {
-        $gui{radiobuttonNewNewHD}->hide();
-        $gui{radiobuttonNewExistingHD}->hide();
-        $gui{tableNewNewHD}->hide();
-        $gui{comboboxNewChooseHD}->hide();
+        $gui{d}{New}{radioNewDisk}->hide();
+        $gui{d}{New}{radioExistingDisk}->hide();
+        $gui{d}{New}{HD}->hide();
+        $gui{d}{New}{cboxExistingDisk}->hide();
     }
 }
 
 # Handle the generate new MACs depending on clone type
 sub clone_type {
-    if ($gui{comboboxCloneType}->get_active() == 2) { $gui{checkbuttonCloneNewMACs}->hide(); }
+    if ($gui{d}{Clone}{cboxType}->get_active() == 2) { $gui{checkbuttonCloneNewMACs}->hide(); }
     else { $gui{checkbuttonCloneNewMACs}->show(); }
 }
 
 # Handle the radio button sensitivity when selecting an image format when
 # creating a new hd for a new guest
 sub sens_hdformatchanged {
-    my $format = &getsel_combo($gui{comboboxNewNewFormat}, 1);
-    $gui{radiobuttonNewDynamic}->set_active(1);
+    my $format = &getsel_combo($gui{d}{New}{cboxFormat}, 1);
+    $gui{d}{New}{radioDynamic}->set_active(1);
 
     if ($format eq 'vmdk') {
-        $gui{radiobuttonNewDynamic}->set_sensitive(1);
-        $gui{radiobuttonNewFixed}->set_sensitive(1);
-        $gui{radiobuttonNewSplit}->set_sensitive(1);
+        $gui{d}{New}{radioDynamic}->set_sensitive(1);
+        $gui{d}{New}{radioFixed}->set_sensitive(1);
+        $gui{d}{New}{radioSplit}->set_sensitive(1);
     }
     elsif ($format eq 'vdi' or $format eq 'vhd') {
-        $gui{radiobuttonNewDynamic}->set_sensitive(1);
-        $gui{radiobuttonNewFixed}->set_sensitive(1);
-        $gui{radiobuttonNewSplit}->set_sensitive(0);
+        $gui{d}{New}{radioDynamic}->set_sensitive(1);
+        $gui{d}{New}{radioFixed}->set_sensitive(1);
+        $gui{d}{New}{radioSplit}->set_sensitive(0);
     }
     else {
-        $gui{radiobuttonNewDynamic}->set_sensitive(1);
-        $gui{radiobuttonNewFixed}->set_sensitive(0);
-        $gui{radiobuttonNewSplit}->set_sensitive(0);
+        $gui{d}{New}{radioDynamic}->set_sensitive(1);
+        $gui{d}{New}{radioFixed}->set_sensitive(0);
+        $gui{d}{New}{radioSplit}->set_sensitive(0);
     }
 }
 
