@@ -19,8 +19,8 @@ sub show_dialog_vmm {
     &fill_list_vmmfloppy();
     &addrow_msg_log('Retrieved global media information');
     &busy_window($gui{windowMain}, 0);
-    $gui{dialogVMM}->run;
-    $gui{dialogVMM}->hide;
+    $gui{d}{VMM}->run;
+    $gui{d}{VMM}->hide;
 }
 
 # Handles GUI changes when user selects a different tab
@@ -29,44 +29,44 @@ sub vmm_tabchanged {
     &vmm_sens_unselected(); # Reset widgets as they are evaluated later
 
     if ($page == 0) { # We need to re-evaluate selection on tab change
-        $gui{toolbuttonVMMAdd}->set_icon_widget($gui{imgHDAdd32});
-        $gui{toolbuttonVMMCreate}->set_icon_widget($gui{imgHDCreate32});
-        $gui{toolbuttonVMMCreate}->set_sensitive(1);
-        $gui{toolbuttonVMMCopy}->set_icon_widget($gui{imgHDCopy32});
-        $gui{toolbuttonVMMMove}->set_icon_widget($gui{imgHDMove32});
-        $gui{toolbuttonVMMModify}->set_icon_widget($gui{imgHDModify32});
-        $gui{toolbuttonVMMRemove}->set_icon_widget($gui{imgHDRemove32});
-        $gui{toolbuttonVMMRelease}->set_icon_widget($gui{imgHDRelease32});
-        &onsel_list_vmmhd() if ($gui{treeviewVMMHD}->get_selection->get_selected());
+        $gui{d}{VMM}{buttonAdd}->set_icon_widget($gui{d}{VMM}{imgHDAdd});
+        $gui{d}{VMM}{buttonCreate}->set_icon_widget($gui{d}{VMM}{imgHDCreate});
+        $gui{d}{VMM}{buttonCreate}->set_sensitive(1);
+        $gui{d}{VMM}{buttonCopy}->set_icon_widget($gui{d}{VMM}{imgHDCopy});
+        $gui{d}{VMM}{buttonMove}->set_icon_widget($gui{d}{VMM}{imgHDMove});
+        $gui{d}{VMM}{buttonModify}->set_icon_widget($gui{d}{VMM}{imgHDModify});
+        $gui{d}{VMM}{buttonRemove}->set_icon_widget($gui{d}{VMM}{imgHDRemove});
+        $gui{d}{VMM}{buttonRelease}->set_icon_widget($gui{d}{VMM}{imgHDRelease});
+        &onsel_list_vmmhd() if ($gui{d}{VMM}{treeviewHD}->get_selection->get_selected());
     }
     elsif ($page == 1) {
-        $gui{toolbuttonVMMAdd}->set_icon_widget($gui{imgDVDAdd32});
-        $gui{toolbuttonVMMCreate}->set_icon_widget($gui{imgDVDCreate32});
-        $gui{toolbuttonVMMCreate}->set_sensitive(0);
-        $gui{toolbuttonVMMCopy}->set_icon_widget($gui{imgDVDCopy32});
-        $gui{toolbuttonVMMMove}->set_icon_widget($gui{imgDVDMove32});
-        $gui{toolbuttonVMMModify}->set_icon_widget($gui{imgDVDModify32});
-        $gui{toolbuttonVMMRemove}->set_icon_widget($gui{imgDVDRemove32});
-        $gui{toolbuttonVMMRelease}->set_icon_widget($gui{imgDVDRelease32});
-        &onsel_list_vmmdvd() if ($gui{treeviewVMMDVD}->get_selection->get_selected());
+        $gui{d}{VMM}{buttonAdd}->set_icon_widget($gui{d}{VMM}{imgDVDAdd});
+        $gui{d}{VMM}{buttonCreate}->set_icon_widget($gui{d}{VMM}{imgDVDCreate});
+        $gui{d}{VMM}{buttonCreate}->set_sensitive(0);
+        $gui{d}{VMM}{buttonCopy}->set_icon_widget($gui{d}{VMM}{imgDVDCopy});
+        $gui{d}{VMM}{buttonMove}->set_icon_widget($gui{d}{VMM}{imgDVDMove});
+        $gui{d}{VMM}{buttonModify}->set_icon_widget($gui{d}{VMM}{imgDVDModify});
+        $gui{d}{VMM}{buttonRemove}->set_icon_widget($gui{d}{VMM}{imgDVDRemove});
+        $gui{d}{VMM}{buttonRelease}->set_icon_widget($gui{d}{VMM}{imgDVDRelease});
+        &onsel_list_vmmdvd() if ($gui{d}{VMM}{treeviewDVD}->get_selection->get_selected());
     }
     else {
-        $gui{toolbuttonVMMAdd}->set_icon_widget($gui{imgFloppyAdd32});
-        $gui{toolbuttonVMMCreate}->set_icon_widget($gui{imgFloppyCreate32});
-        $gui{toolbuttonVMMCreate}->set_sensitive(1);
-        $gui{toolbuttonVMMCopy}->set_icon_widget($gui{imgFloppyCopy32});
-        $gui{toolbuttonVMMMove}->set_icon_widget($gui{imgFloppyMove32});
-        $gui{toolbuttonVMMModify}->set_icon_widget($gui{imgFloppyModify32});
-        $gui{toolbuttonVMMRemove}->set_icon_widget($gui{imgFloppyRemove32});
-        $gui{toolbuttonVMMRelease}->set_icon_widget($gui{imgFloppyRelease32});
-        &onsel_list_vmmfloppy() if ($gui{treeviewVMMFloppy}->get_selection->get_selected());
+        $gui{d}{VMM}{buttonAdd}->set_icon_widget($gui{d}{VMM}{imgFDAdd});
+        $gui{d}{VMM}{buttonCreate}->set_icon_widget($gui{d}{VMM}{imgFDCreate});
+        $gui{d}{VMM}{buttonCreate}->set_sensitive(1);
+        $gui{d}{VMM}{buttonCopy}->set_icon_widget($gui{d}{VMM}{imgFDCopy});
+        $gui{d}{VMM}{buttonMove}->set_icon_widget($gui{d}{VMM}{imgFDMove});
+        $gui{d}{VMM}{buttonModify}->set_icon_widget($gui{d}{VMM}{imgFDModify});
+        $gui{d}{VMM}{buttonRemove}->set_icon_widget($gui{d}{VMM}{imgFDRemove});
+        $gui{d}{VMM}{buttonRelease}->set_icon_widget($gui{d}{VMM}{imgFDRelease});
+        &onsel_list_vmmfloppy() if ($gui{d}{VMM}{treeviewFD}->get_selection->get_selected());
     }
 }
 
 # Releases a medium from a guest
 sub vmm_release {
     my $mediumref;
-    my $page = $gui{notebookVMM}->get_current_page();
+    my $page = $gui{d}{VMM}{notebook}->get_current_page();
     my $warn = 0;
 
     if ($page == 0) { $mediumref = &getsel_list_vmmhd(); }
@@ -108,12 +108,12 @@ sub vmm_release {
 }
 
 sub vmm_rem {
-    my $page = $gui{notebookVMM}->get_current_page();
+    my $page = $gui{d}{VMM}{notebook}->get_current_page();
 
     if ($page == 0) {
         my $hdref = &getsel_list_vmmhd();
-        my $response = $gui{dialogVMMRemoveDelete}->run;
-        $gui{dialogVMMRemoveDelete}->hide;
+        my $response = $gui{d}{RemoveHD}->run;
+        $gui{d}{RemoveHD}->hide;
 
         if ($response eq '1') { # Deletes Disk (not cancellable)
             my $MediumState = IMedium_refreshState($$hdref{IMedium});
@@ -161,7 +161,7 @@ sub vmm_compact {
 
 # Move a medium to a new location
 sub vmm_move_broker {
-    my $page = $gui{notebookVMM}->get_current_page();
+    my $page = $gui{d}{VMM}{notebook}->get_current_page();
     my $mediumref;
 
     if ($page == 0) {
@@ -181,7 +181,7 @@ sub vmm_move_broker {
 # Adds a harddisk/dvd/floppy image to the VMM
 sub vmm_add {
     my ($basedir, $filearrayref) = @_;
-    my $page = $gui{notebookVMM}->get_current_page();
+    my $page = $gui{d}{VMM}{notebook}->get_current_page();
     return if (!$basedir);
 
     if ($page == 0) {
@@ -215,7 +215,7 @@ sub vmm_add {
 
 # Refreshes the media on the currently selected page
 sub vmm_refresh_broker {
-    my $page = $gui{notebookVMM}->get_current_page();
+    my $page = $gui{d}{VMM}{notebook}->get_current_page();
 
     if ($page == 0) { &fill_list_vmmhd(); }
     elsif ($page == 1) { &fill_list_vmmdvd(); }
@@ -224,7 +224,7 @@ sub vmm_refresh_broker {
 
 # Selects the type of media to create
 sub vmm_create_broker {
-    my $page = $gui{notebookVMM}->get_current_page();
+    my $page = $gui{d}{VMM}{notebook}->get_current_page();
     my $vhost = &vhost();
 
     if ($page == 0) { &show_dialog_create_hd(undef, {IMachine => '', filename => &rcatfile($$vhost{machinedir}, 'HardDisk-' . int(rand(999999))), callback => \&vmm_refresh_broker}); }
@@ -234,7 +234,7 @@ sub vmm_create_broker {
 
 # Selects the type of media to copy and convert
 sub vmm_copy_broker {
-    my $page = $gui{notebookVMM}->get_current_page();
+    my $page = $gui{d}{VMM}{notebook}->get_current_page();
 
     if ($page == 0) { &show_dialog_vmm_copy_hd(); }
     elsif ($page == 1) { } # Not implemented yet
@@ -245,16 +245,17 @@ sub vmm_copy_broker {
 sub show_dialog_vmm_move {
     my ($mediumref, $devicetype) = @_;
     my $vhost = &vhost();
-    $gui{entryMoveMediumSource}->set_text($$mediumref{Location});
-    $gui{entryMoveMediumTo}->set_text(&rcatfile($$vhost{machinedir}, $$mediumref{Name}));
+    $gui{d}{MoveMedium}{entrySrc}->set_text($$mediumref{Location});
+    $gui{d}{MoveMedium}{entryDst}->set_text(&rcatfile($$vhost{machinedir}, $$mediumref{Name}));
 
-    my $response = $gui{dialogVMMMoveMedium}->run;
-    $gui{dialogVMMMoveMedium}->hide();
+    $gui{d}{MoveMedium}->show_all;
+    my $response = $gui{d}{MoveMedium}->run;
+    $gui{d}{MoveMedium}->hide();
 
     if ($response eq 'ok') {
-        my $IProgress = IMedium_moveTo($$mediumref{IMedium}, $gui{entryMoveMediumTo}->get_text());
+        my $IProgress = IMedium_moveTo($$mediumref{IMedium}, $gui{d}{MoveMedium}{entryDst}->get_text());
         &show_progress_window($IProgress, 'Moving medium', $gui{pb}{ProgressMediaMove}) if ($IProgress); # Note: An $IProgress is not always returned for move operations are some are very quick
-        &addrow_msg_log('Moved medium ' . $$mediumref{Location} . ' to ' . $gui{entryMoveMediumTo}->get_text());
+        &addrow_msg_log('Moved medium ' . $$mediumref{Location} . ' to ' . $gui{d}{MoveMedium}{entryDst}->get_text());
 
         if ($devicetype eq 'HardDisk') { &fill_list_vmmhd(); }
         elsif ($devicetype eq 'DVD') { &fill_list_vmmdvd(); }
@@ -267,17 +268,17 @@ sub show_dialog_vmm_modify {
     my $vhost = &vhost();
     my $hdref = &getsel_list_vmmhd();
     my $hdsizemb = ceil($$hdref{LsizeInt} / 1048576);
-    $gui{spinbuttonVMMModifyResizeHD}->set_range($hdsizemb, $$vhost{maxhdsizemb}); # Images cannot be shrunk, so pin the lowest value to the current disks size
-    $gui{spinbuttonVMMModifyResizeHD}->set_value($hdsizemb);
-    $gui{entryVMMModifySource}->set_text($$hdref{Name});
-    &combobox_set_active_text($gui{comboboxVMMModifyType}, $$hdref{Type}, 0);
-    my $response = $gui{dialogVMMModify}->run;
-    $gui{dialogVMMModify}->hide;
+    $gui{d}{ModifyHD}{sbSize}->set_range($hdsizemb, $$vhost{maxhdsizemb}); # Images cannot be shrunk, so pin the lowest value to the current disks size
+    $gui{d}{ModifyHD}{sbSize}->set_value($hdsizemb);
+    $gui{d}{ModifyHD}{entryHD}->set_text($$hdref{Name});
+    &combobox_set_active_text($gui{d}{ModifyHD}{cboxType}, $$hdref{Type}, 0);
+    my $response = $gui{d}{ModifyHD}->run;
+    $gui{d}{ModifyHD}->hide;
 
     if ($response eq 'ok') {
-        my $newhdsizemb = $gui{spinbuttonVMMModifyResizeHD}->get_value_as_int(); # Do any resize first because it may not be possible once the type has changed
+        my $newhdsizemb = $gui{d}{ModifyHD}{sbSize}->get_value_as_int(); # Do any resize first because it may not be possible once the type has changed
 
-        if ($newhdsizemb > $hdsizemb and $gui{checkbuttonVMMModifyResizeHD}->get_active()) {
+        if ($newhdsizemb > $hdsizemb and $gui{d}{ModifyHD}{checkResize}->get_active()) {
             &addrow_msg_log("Resizing $$hdref{Name} ($hdsizemb MB -> $newhdsizemb MB)");
             my $IProgress = IMedium_resize($$hdref{IMedium}, ($newhdsizemb * 1048576));
             &show_progress_window($IProgress, 'Resizing Virtual Hard Disk Image', $gui{pb}{ProgressMediaResize}) if ($IProgress);
@@ -286,7 +287,7 @@ sub show_dialog_vmm_modify {
             &show_err_msg('nohdresize', "\nMedium: $$hdref{Name}\nCurrent State: $MediumState") if (($refreshsize / 1048576) < $newhdsizemb); # See if actually got resized, not all types support resizing
         }
 
-        my $newtype = &getsel_combo($gui{comboboxVMMModifyType}, 0);
+        my $newtype = &getsel_combo($gui{d}{ModifyHD}{cboxType}, 0);
 
         if ($$hdref{Type} ne $newtype) {
             &addrow_msg_log("Modifying image type of $$hdref{Name} ($$hdref{Type} -> $newtype)");
@@ -300,30 +301,30 @@ sub show_dialog_vmm_modify {
 # Displays the copy and convert hard disk window
 sub show_dialog_vmm_copy_hd {
     my $hdref = &getsel_list_vmmhd();
-    $gui{entryCopyHDSource}->set_text($$hdref{Location});
+    $gui{d}{CopyHD}{entrySource}->set_text($$hdref{Location});
     my $newdisk = $$hdref{Location};
     $newdisk =~ m/(.*)\.[^.]+$/; # Strip any extension
-    $gui{entryCopyHDName}->set_text($1 . '-copy-' . int(rand(999999)));
-    $gui{comboboxCopyHDFormat}->set_active(0);
-    $gui{radiobuttonCopyHDDynamic}->set_sensitive(1);
-    $gui{radiobuttonCopyHDDynamic}->set_active(1);
-    $gui{radiobuttonCopyHDFixed}->set_sensitive(1);
-    $gui{radiobuttonCopyHDSplit}->set_sensitive(0);
-    my $response = $gui{dialogVMMCopyHD}->run;
-    $gui{dialogVMMCopyHD}->hide();
+    $gui{d}{CopyHD}{entryDest}->set_text($1 . '-copy-' . int(rand(999999)));
+    $gui{d}{CopyHD}{cboxFormat}->set_active(0);
+    $gui{d}{CopyHD}{radioDynamic}->set_sensitive(1);
+    $gui{d}{CopyHD}{radioDynamic}->set_active(1);
+    $gui{d}{CopyHD}{radioFixed}->set_sensitive(1);
+    $gui{d}{CopyHD}{radioSplit}->set_sensitive(0);
+    my $response = $gui{d}{CopyHD}->run;
+    $gui{d}{CopyHD}->hide();
 
     if ($response eq 'ok') {
-        my ($vol, $dir, $file) = &rsplitpath($gui{entryCopyHDName}->get_text());
+        my ($vol, $dir, $file) = &rsplitpath($gui{d}{CopyHD}{entryDest}->get_text());
         my $variant = 'Standard'; # Standard is Dynamic
 
-        if ($gui{radiobuttonCopyHDFixed}->get_active()) { $variant = 'Fixed'; }
-        elsif ($gui{radiobuttonCopyHDSplit}->get_active()) { $variant = 'VmdkSplit2G'; }
+        if ($gui{d}{CopyHD}{radioFixed}->get_active()) { $variant = 'Fixed'; }
+        elsif ($gui{d}{CopyHD}{radioSplit}->get_active()) { $variant = 'VmdkSplit2G'; }
 
         my %clonehd =   (diskname   => $file,
                          devicetype => 'HardDisk',
                          mode       => 'ReadWrite',
                          allocation => $variant,
-                         imgformat  =>  &getsel_combo($gui{comboboxCopyHDFormat}, 1),
+                         imgformat  =>  &getsel_combo($gui{d}{CopyHD}{cboxFormat}, 1),
                          location   => $vol . $dir);
         my $srchdref = &getsel_list_vmmhd();
         &create_new_dskimg_clone(\%clonehd, $$srchdref{IMedium});
@@ -336,13 +337,14 @@ sub show_dialog_vmm_copy_floppy {
     my $fdref = &getsel_list_vmmfloppy();
     my $newfloppy = $$fdref{Location};
     $newfloppy =~ m/(.*)\.[^.]+$/; # Strip any extension
-    $gui{entryVMMCopyFloppyName}->set_text($1 . '-copy-' . int(rand(999999)));
-    $gui{entryVMMCopyFloppySource}->set_text($$fdref{Location});
-    my $response = $gui{dialogVMMCopyFloppy}->run;
-    $gui{dialogVMMCopyFloppy}->hide();
+    $gui{d}{CopyFloppy}{entryDst}->set_text($1 . '-copy-' . int(rand(999999)));
+    $gui{d}{CopyFloppy}{entrySrc}->set_text($$fdref{Location});
+    $gui{d}{CopyFloppy}->show_all;
+    my $response = $gui{d}{CopyFloppy}->run();
+    $gui{d}{CopyFloppy}->hide();
 
     if ($response eq 'ok') {
-        my ($vol, $dir, $file) = &rsplitpath($gui{entryVMMCopyFloppyName}->get_text());
+        my ($vol, $dir, $file) = &rsplitpath($gui{d}{CopyFloppy}{entryDst}->get_text());
 
             my %clonefd = (diskname   => $file,
                            devicetype => 'Floppy',
@@ -358,39 +360,39 @@ sub show_dialog_vmm_copy_floppy {
 
 # Handle the radio button sensitivity when selecting an image format for copying
 sub sens_copyhdformat {
-    my $format = &getsel_combo($gui{comboboxCopyHDFormat}, 1);
-    $gui{radiobuttonCopyHDDynamic}->set_active(1);
+    my $format = &getsel_combo($gui{d}{CopyHD}{cboxFormat}, 1);
+    $gui{d}{CopyHD}{radioDynamic}->set_active(1);
 
     if ($format eq 'vmdk') {
-        $gui{radiobuttonCopyHDDynamic}->set_sensitive(1);
-        $gui{radiobuttonCopyHDFixed}->set_sensitive(1);
-        $gui{radiobuttonCopyHDSplit}->set_sensitive(1);
+        $gui{d}{CopyHD}{radioDynamic}->set_sensitive(1);
+        $gui{d}{CopyHD}{radioFixed}->set_sensitive(1);
+        $gui{d}{CopyHD}{radioSplit}->set_sensitive(1);
     }
     elsif ($format eq 'vdi' or $format eq 'vhd') {
-        $gui{radiobuttonCopyHDDynamic}->set_sensitive(1);
-        $gui{radiobuttonCopyHDFixed}->set_sensitive(1);
-        $gui{radiobuttonCopyHDSplit}->set_sensitive(0);
+        $gui{d}{CopyHD}{radioDynamic}->set_sensitive(1);
+        $gui{d}{CopyHD}{radioFixed}->set_sensitive(1);
+        $gui{d}{CopyHD}{radioSplit}->set_sensitive(0);
     }
     else {
-        $gui{radiobuttonCopyHDDynamic}->set_sensitive(1);
-        $gui{radiobuttonCopyHDFixed}->set_sensitive(0);
-        $gui{radiobuttonCopyHDSplit}->set_sensitive(0);
+        $gui{d}{CopyHD}{radioDynamic}->set_sensitive(1);
+        $gui{d}{CopyHD}{radioFixed}->set_sensitive(0);
+        $gui{d}{CopyHD}{radioSplit}->set_sensitive(0);
     }
 }
 
 # Run when there are no devices selected in the VMM and between tab changes
 sub vmm_sens_unselected {
-    $gui{labelVMMTypeField}->set_text('');
-    $gui{labelVMMAttachedToField}->set_text('');
-    $gui{labelVMMLocationField}->set_text('');
-    $gui{labelVMMEncryptedField}->set_text('');
-    $gui{labelVMMUUIDField}->set_text('');
-    $gui{toolbuttonVMMRemove}->set_sensitive(0);
-    $gui{toolbuttonVMMCopy}->set_sensitive(0);
-    $gui{toolbuttonVMMMove}->set_sensitive(0);
-    $gui{toolbuttonVMMModify}->set_sensitive(0);
-    $gui{toolbuttonVMMRelease}->set_sensitive(0);
-    $gui{toolbuttonVMMCompact}->set_sensitive(0);
+    $gui{d}{VMM}{labelType}->set_text('');
+    $gui{d}{VMM}{labelAttachedTo}->set_text('');
+    $gui{d}{VMM}{labelLocation}->set_text('');
+    $gui{d}{VMM}{labelEncrypted}->set_text('');
+    $gui{d}{VMM}{labelUUID}->set_text('');
+    $gui{d}{VMM}{buttonRemove}->set_sensitive(0);
+    $gui{d}{VMM}{buttonCopy}->set_sensitive(0);
+    $gui{d}{VMM}{buttonMove}->set_sensitive(0);
+    $gui{d}{VMM}{buttonModify}->set_sensitive(0);
+    $gui{d}{VMM}{buttonRelease}->set_sensitive(0);
+    $gui{d}{VMM}{buttonCompact}->set_sensitive(0);
 }
 
 # Changes the sensitivity of resize widgets depending if the user selects that option
@@ -398,7 +400,7 @@ sub vmm_modify_sens_resize {
     my ($widget) = @_;
     my $state = $widget->get_active();
     $gui{labelVMMModifyResizeHD}->set_sensitive($state);
-    $gui{spinbuttonVMMModifyResizeHD}->set_sensitive($state);
+    $gui{d}{ModifyHD}{sbSize}->set_sensitive($state);
 }
 
 # Displays the create a new floppy disk dialog. Creates & attaches based on options
@@ -406,80 +408,81 @@ sub vmm_modify_sens_resize {
 sub show_dialog_create_floppy {
     my ($widget, $data) = @_;
     my $callback = $$data{callback};
-    $gui{comboboxCreateFloppySize}->set_active(1);
-    $gui{entryCreateFloppyName}->set_text($$data{filename});
+    $gui{d}{CreateFloppy}{cboxSize}->set_active(1);
+    $gui{d}{CreateFloppy}{entryImage}->set_text($$data{filename});
 
     do {
-        my $response = $gui{dialogCreateFloppy}->run;
+        $gui{d}{CreateFloppy}->show_all;
+        my $response = $gui{d}{CreateFloppy}->run();
 
         if ($response eq 'ok') {
             # No validation needed on other entries
-            if (!$gui{entryCreateFloppyName}->get_text()) { &show_err_msg('invalidname'); }
+            if (!$gui{d}{CreateFloppy}{entryImage}->get_text()) { &show_err_msg('invalidname'); }
             else {
-                $gui{dialogCreateFloppy}->hide;
-                my ($vol, $dir, $file) = &rsplitpath($gui{entryCreateFloppyName}->get_text());
+                $gui{d}{CreateFloppy}->hide;
+                my ($vol, $dir, $file) = &rsplitpath($gui{d}{CreateFloppy}{entryImage}->get_text());
                 my $alloc = ['Fixed'];
-                $alloc = ['Fixed', 'Formatted'] if ($gui{checkbuttonCreateFloppyFAT12}->get_active());
+                $alloc = ['Fixed', 'Formatted'] if ($gui{d}{CreateFloppy}{checkFAT12}->get_active());
 
                 my %newfloppy = (diskname   => $file,
                                  devicetype => 'Floppy',
                                  mode       => 'ReadWrite',
-                                 size       => &getsel_combo($gui{comboboxCreateFloppySize}, 1),
+                                 size       => &getsel_combo($gui{d}{CreateFloppy}{cboxSize}, 1),
                                  allocation => $alloc,
                                  imgformat  => 'raw',
                                  location   => $vol . $dir);
 
                 my $IMedium = &create_new_dskimg(\%newfloppy);
                 # Execute the callback. First paramater is calling widget
-                &$callback($gui{dialogCreateFloppy}, {IMedium => $IMedium, type => 'Floppy'}) if ($callback);
+                &$callback($gui{d}{CreateFloppy}, {IMedium => $IMedium, type => 'Floppy'}) if ($callback);
             }
         }
-        else { $gui{dialogCreateFloppy}->hide; }
+        else { $gui{d}{CreateFloppy}->hide; }
 
-    } until (!$gui{dialogCreateFloppy}->get_visible());
+    } until (!$gui{d}{CreateFloppy}->get_visible());
 }
 
 # Displays the create a new hard disk dialog. Creates & attaches based on options
 sub show_dialog_create_hd {
     my ($widget, $data) = @_;
     my $vhost = &vhost();
-    $gui{entryCreateHDName}->set_text($$data{filename});
-    $gui{comboboxCreateHDFormat}->set_active(0);
-    $gui{radiobuttonCreateHDDynamic}->show();
-    $gui{radiobuttonCreateHDFixed}->show();
-    $gui{radiobuttonCreateHDSplit}->hide();
-    $gui{spinbuttonCreateHDSize}->set_range($$vhost{minhdsizemb}, $$vhost{maxhdsizemb});
-    $gui{spinbuttonCreateHDSize}->set_value(8192.00);
+    $gui{d}{CreateHD}{entryImage}->set_text($$data{filename});
+    $gui{d}{CreateHD}{cboxFormat}->set_active(0);
+    $gui{d}{CreateHD}{radioDynamic}->show();
+    $gui{d}{CreateHD}{radioFixed}->show();
+    $gui{d}{CreateHD}{radioSplit}->hide();
+    $gui{d}{CreateHD}{sbSize}->set_range($$vhost{minhdsizemb}, $$vhost{maxhdsizemb});
+    $gui{d}{CreateHD}{sbSize}->set_value(8192.00);
 
     do {
-        my $response = $gui{dialogCreateHD}->run;
+        my $response = $gui{d}{CreateHD}->run;
 
         if ($response eq 'ok') {
             # No validation needed on other entries
-            if (!$gui{entryCreateHDName}->get_text()) { &show_err_msg('invalidname'); }
+            if (!$gui{d}{CreateHD}{entryImage}->get_text()) { &show_err_msg('invalidname'); }
             else {
-                $gui{dialogCreateHD}->hide;
-                my ($vol, $dir, $file) = &rsplitpath($gui{entryCreateHDName}->get_text());
+                $gui{d}{CreateHD}->hide;
+                my ($vol, $dir, $file) = &rsplitpath($gui{d}{CreateHD}{entryImage}->get_text());
 
                 my %newhd = (diskname   => $file,
                              devicetype => 'HardDisk',
                              mode       => 'ReadWrite',
-                             size       => $gui{spinbuttonCreateHDSize}->get_value_as_int() * 1048576,
+                             size       => $gui{d}{CreateHD}{sbSize}->get_value_as_int() * 1048576,
                              allocation => ['Standard'], # Standard == Dynamic Allocation
-                             imgformat  => &getsel_combo($gui{comboboxCreateHDFormat}, 1),
+                             imgformat  => &getsel_combo($gui{d}{CreateHD}{cboxFormat}, 1),
                              location   => $vol . $dir);
 
-                if ($gui{radiobuttonCreateHDFixed}->get_active()) { $newhd{allocation} = ['Fixed']; }
-                elsif ($gui{radiobuttonCreateHDSplit}->get_active()) { $newhd{allocation} = ['VmdkSplit2G']; }
+                if ($gui{d}{CreateHD}{radioFixed}->get_active()) { $newhd{allocation} = ['Fixed']; }
+                elsif ($gui{d}{CreateHD}{radioSplit}->get_active()) { $newhd{allocation} = ['VmdkSplit2G']; }
                 my $IMedium = &create_new_dskimg(\%newhd);
 
                 # Execute the callback. First paramater is calling widget
-                &{$$data{callback}}($gui{dialogCreateHD}, {IMedium => $IMedium, type => 'HardDisk'}) if ($$data{callback});
+                &{$$data{callback}}($gui{d}{CreateHD}, {IMedium => $IMedium, type => 'HardDisk'}) if ($$data{callback});
             }
         }
-        else { $gui{dialogCreateHD}->hide; }
+        else { $gui{d}{CreateHD}->hide; }
 
-    } until (!$gui{dialogCreateHD}->get_visible());
+    } until (!$gui{d}{CreateHD}->get_visible());
 }
 
 1;
